library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;

entity multi_prbsgenerate_256bit is
PORT(
	coreclk  	: in std_logic;
	Enable		: in std_logic;
	StartValue	: in std_logic_vector(255 downto 0);
	Reset	 	: in std_logic;
	PrbsSelect	: in std_logic_vector(1 downto 0);
	Inserterror : in std_logic;
	Prbsout 	: out std_logic_vector(255 downto 0);
	Valid		: out std_logic;
	deskew_pulse : out std_logic -- Only for E-tile
	);
END multi_prbsgenerate_256bit;	


architecture rtl of multi_prbsgenerate_256bit is


component Synchro is
port
	(
	Clk			: in std_logic;
	data_in		: in std_logic;
	data_out		: out std_logic
	);
end component;


signal prbs 			: std_logic_vector(255 downto 0) := (OTHERS => '0');
signal tx_data 			: std_logic_vector(255 downto 0);
signal tx_data_sig 		: std_logic_vector(255 downto 0) := (OTHERS => '0');
signal detect_inserterror	: std_logic;
signal delayed_error    : std_logic;
signal inserterror_Q	: std_logic;
signal inserterror_synchro	: std_logic;

signal PrbsSelect_s1, PrbsSelect_s2, PrbsSelect_s3 : std_logic_vector(1 downto 0); 

signal Reset_dupA1, Reset_dupA2 :  std_logic :='0';
attribute preserve_syn_only : boolean;
attribute preserve_syn_only of Reset_dupA1 : signal is true;
signal count_deskew		: std_logic_Vector(1 downto 0);
signal Valid_min1 		: std_logic;


begin

Synchro_inst : Synchro
port map(
Clk 			=> coreclk,
data_in 		=> inserterror,
data_out 	=> inserterror_synchro
);

process(coreclk)
	begin
	if rising_edge(coreclk) then
				Reset_dupA1 <= Reset;
				Reset_dupA2 <= Reset_dupA1;	
		if (Reset_dupA2 = '1') then
				prbs <= StartValue;
				--count <= (OTHERS => '0');
				PrbsSelect_s1 <= (OTHERS => '0'); 
				PrbsSelect_s2 <= (OTHERS => '0'); 
				PrbsSelect_s3 <= (OTHERS => '0'); 

		else
				PrbsSelect_s1 <= PrbsSelect; 
				PrbsSelect_s2 <= PrbsSelect_s1; 
				PrbsSelect_s3 <= PrbsSelect_s2; 

		if Enable = '1' then
			CASE PrbsSelect_s3 IS


				WHEN "00" =>		-- PRBS 2^13-1 (PRBS13 [13,12,2,1] (parallel 256-bit serializer)			
					prbs(0) <= prbs(6) XOR prbs(9) XOR prbs(10);
					prbs(1) <= prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(2) <= prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(3) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(9);
					prbs(4) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(10);
					prbs(5) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(11);
					prbs(6) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(12);
					prbs(7) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(12);
					prbs(8) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(12);
					prbs(9) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(12);
					prbs(10) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(12);
					prbs(11) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(12) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(13) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(14) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(15) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(16) <= prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(17) <= prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(18) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(19) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(20) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(21) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(22) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(23) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(7) XOR prbs(8) XOR prbs(9);
					prbs(24) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(25) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(26) <= prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(27) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(11);
					prbs(28) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(12);
					prbs(29) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(12);
					prbs(30) <= prbs(0) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(12);
					prbs(31) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(32) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10);
					prbs(33) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(34) <= prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(35) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(10);
					prbs(36) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(37) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(38) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9);
					prbs(39) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10);
					prbs(40) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(41) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(42) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(43) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(44) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(45) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(46) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(47) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(48) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(49) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(50) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(51) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(52) <= prbs(0) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(53) <= prbs(1) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(54) <= prbs(0) XOR prbs(1) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(55) <= prbs(1) XOR prbs(2) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(56) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(8) XOR prbs(10);
					prbs(57) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(9) XOR prbs(11);
					prbs(58) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(10) XOR prbs(12);
					prbs(59) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(11) XOR prbs(12);
					prbs(60) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7);
					prbs(61) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8);
					prbs(62) <= prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9);
					prbs(63) <= prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(64) <= prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(65) <= prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(66) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(67) <= prbs(0) XOR prbs(3) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(68) <= prbs(1) XOR prbs(4) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(69) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(9);
					prbs(70) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(10);
					prbs(71) <= prbs(2) XOR prbs(3) XOR prbs(7) XOR prbs(11);
					prbs(72) <= prbs(3) XOR prbs(4) XOR prbs(8) XOR prbs(12);
					prbs(73) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(9) XOR prbs(12);
					prbs(74) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(10) XOR prbs(12);
					prbs(75) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(11) XOR prbs(12);
					prbs(76) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(8);
					prbs(77) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(9);
					prbs(78) <= prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(10);
					prbs(79) <= prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(80) <= prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(81) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(82) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(83) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(84) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(85) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(11);
					prbs(86) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(12);
					prbs(87) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(88) <= prbs(0) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9);
					prbs(89) <= prbs(1) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(90) <= prbs(2) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(91) <= prbs(3) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(92) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(10) XOR prbs(11);
					prbs(93) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(11) XOR prbs(12);
					prbs(94) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6);
					prbs(95) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7);
					prbs(96) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8);
					prbs(97) <= prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9);
					prbs(98) <= prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(99) <= prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(100) <= prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(101) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(102) <= prbs(0) XOR prbs(3) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(103) <= prbs(1) XOR prbs(4) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(104) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(105) <= prbs(0) XOR prbs(6) XOR prbs(11);
					prbs(106) <= prbs(1) XOR prbs(7) XOR prbs(12);
					prbs(107) <= prbs(0) XOR prbs(1) XOR prbs(8) XOR prbs(12);
					prbs(108) <= prbs(0) XOR prbs(9) XOR prbs(12);
					prbs(109) <= prbs(0) XOR prbs(2) XOR prbs(10) XOR prbs(12);
					prbs(110) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(11) XOR prbs(12);
					prbs(111) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4);
					prbs(112) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5);
					prbs(113) <= prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6);
					prbs(114) <= prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7);
					prbs(115) <= prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8);
					prbs(116) <= prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(9);
					prbs(117) <= prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(118) <= prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(119) <= prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(120) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(9) XOR prbs(11);
					prbs(121) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(10) XOR prbs(12);
					prbs(122) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(11) XOR prbs(12);
					prbs(123) <= prbs(0) XOR prbs(4) XOR prbs(5);
					prbs(124) <= prbs(1) XOR prbs(5) XOR prbs(6);
					prbs(125) <= prbs(2) XOR prbs(6) XOR prbs(7);
					prbs(126) <= prbs(3) XOR prbs(7) XOR prbs(8);
					prbs(127) <= prbs(4) XOR prbs(8) XOR prbs(9);
					prbs(128) <= prbs(5) XOR prbs(9) XOR prbs(10);
					prbs(129) <= prbs(6) XOR prbs(10) XOR prbs(11);
					prbs(130) <= prbs(7) XOR prbs(11) XOR prbs(12);
					prbs(131) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(8);
					prbs(132) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(9);
					prbs(133) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(10);
					prbs(134) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(11);
					prbs(135) <= prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(12);
					prbs(136) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(12);
					prbs(137) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(12);
					prbs(138) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(12);
					prbs(139) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(140) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(141) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(142) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(143) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9);
					prbs(144) <= prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(145) <= prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(146) <= prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(147) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(148) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(149) <= prbs(1) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(150) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(11);
					prbs(151) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(12);
					prbs(152) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(153) <= prbs(0) XOR prbs(4) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(154) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(9) XOR prbs(11);
					prbs(155) <= prbs(1) XOR prbs(3) XOR prbs(6) XOR prbs(10) XOR prbs(12);
					prbs(156) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(11) XOR prbs(12);
					prbs(157) <= prbs(0) XOR prbs(5) XOR prbs(8);
					prbs(158) <= prbs(1) XOR prbs(6) XOR prbs(9);
					prbs(159) <= prbs(2) XOR prbs(7) XOR prbs(10);
					prbs(160) <= prbs(3) XOR prbs(8) XOR prbs(11);
					prbs(161) <= prbs(4) XOR prbs(9) XOR prbs(12);
					prbs(162) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(10) XOR prbs(12);
					prbs(163) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(11) XOR prbs(12);
					prbs(164) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(7);
					prbs(165) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(8);
					prbs(166) <= prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(9);
					prbs(167) <= prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(10);
					prbs(168) <= prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(11);
					prbs(169) <= prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(12);
					prbs(170) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(12);
					prbs(171) <= prbs(0) XOR prbs(3) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(172) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(8) XOR prbs(10);
					prbs(173) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(9) XOR prbs(11);
					prbs(174) <= prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(10) XOR prbs(12);
					prbs(175) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(11) XOR prbs(12);
					prbs(176) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(8);
					prbs(177) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(9);
					prbs(178) <= prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(10);
					prbs(179) <= prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(11);
					prbs(180) <= prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(12);
					prbs(181) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(182) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(10);
					prbs(183) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(184) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(185) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(9);
					prbs(186) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(10);
					prbs(187) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(11);
					prbs(188) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(12);
					prbs(189) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(12);
					prbs(190) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(191) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9);
					prbs(192) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(193) <= prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(194) <= prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(195) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(196) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(197) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(10);
					prbs(198) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(11);
					prbs(199) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(12);
					prbs(200) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(201) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(202) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(203) <= prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(204) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(205) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(206) <= prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(207) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(208) <= prbs(0) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(209) <= prbs(1) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(210) <= prbs(0) XOR prbs(1) XOR prbs(8) XOR prbs(9);
					prbs(211) <= prbs(1) XOR prbs(2) XOR prbs(9) XOR prbs(10);
					prbs(212) <= prbs(2) XOR prbs(3) XOR prbs(10) XOR prbs(11);
					prbs(213) <= prbs(3) XOR prbs(4) XOR prbs(11) XOR prbs(12);
					prbs(214) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5);
					prbs(215) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6);
					prbs(216) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7);
					prbs(217) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8);
					prbs(218) <= prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9);
					prbs(219) <= prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10);
					prbs(220) <= prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11);
					prbs(221) <= prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(12);
					prbs(222) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(223) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(224) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(225) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(11);
					prbs(226) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(12);
					prbs(227) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(12);
					prbs(228) <= prbs(0) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(12);
					prbs(229) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(12);
					prbs(230) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(231) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(232) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(233) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(234) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(235) <= prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(236) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(9);
					prbs(237) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(10);
					prbs(238) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(11);
					prbs(239) <= prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(240) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(10) XOR prbs(11);
					prbs(241) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(11) XOR prbs(12);
					prbs(242) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9);
					prbs(243) <= prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10);
					prbs(244) <= prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(245) <= prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(246) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(247) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(248) <= prbs(1) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(249) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(250) <= prbs(0) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(11);
					prbs(251) <= prbs(1) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(12);
					prbs(252) <= prbs(0) XOR prbs(1) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(12);
					prbs(253) <= prbs(0) XOR prbs(9) XOR prbs(11);
					prbs(254) <= prbs(1) XOR prbs(10) XOR prbs(12);
					prbs(255) <= prbs(0) XOR prbs(1) XOR prbs(11) XOR prbs(12);

								
				WHEN "01" =>	-- PRBS 2^23-1 [23,18] (parallel 256bit serializer) 
				
					prbs(0) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(14) XOR prbs(16) XOR prbs(19) XOR prbs(20) XOR prbs(21);
					prbs(1) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(15) XOR prbs(17) XOR prbs(20) XOR prbs(21) XOR prbs(22);
					prbs(2) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(16) XOR prbs(21) XOR prbs(22);
					prbs(3) <= prbs(0) XOR prbs(1) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(17) XOR prbs(18) XOR prbs(22);
					prbs(4) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(19);
					prbs(5) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(20);
					prbs(6) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(21);
					prbs(7) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(22);
					prbs(8) <= prbs(0) XOR prbs(4) XOR prbs(5) XOR prbs(6) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(18);
					prbs(9) <= prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(7) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(19);
					prbs(10) <= prbs(2) XOR prbs(6) XOR prbs(7) XOR prbs(8) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(20);
					prbs(11) <= prbs(3) XOR prbs(7) XOR prbs(8) XOR prbs(9) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(21);
					prbs(12) <= prbs(4) XOR prbs(8) XOR prbs(9) XOR prbs(10) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(22);
					prbs(13) <= prbs(0) XOR prbs(5) XOR prbs(9) XOR prbs(10) XOR prbs(11) XOR prbs(13) XOR prbs(16) XOR prbs(18) XOR prbs(19);
					prbs(14) <= prbs(1) XOR prbs(6) XOR prbs(10) XOR prbs(11) XOR prbs(12) XOR prbs(14) XOR prbs(17) XOR prbs(19) XOR prbs(20);
					prbs(15) <= prbs(2) XOR prbs(7) XOR prbs(11) XOR prbs(12) XOR prbs(13) XOR prbs(15) XOR prbs(18) XOR prbs(20) XOR prbs(21);
					prbs(16) <= prbs(3) XOR prbs(8) XOR prbs(12) XOR prbs(13) XOR prbs(14) XOR prbs(16) XOR prbs(19) XOR prbs(21) XOR prbs(22);
					prbs(17) <= prbs(0) XOR prbs(4) XOR prbs(9) XOR prbs(13) XOR prbs(14) XOR prbs(15) XOR prbs(17) XOR prbs(18) XOR prbs(20) XOR prbs(22);
					prbs(18) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(10) XOR prbs(14) XOR prbs(15) XOR prbs(16) XOR prbs(19) XOR prbs(21);
					prbs(19) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(11) XOR prbs(15) XOR prbs(16) XOR prbs(17) XOR prbs(20) XOR prbs(22);
					prbs(20) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(7) XOR prbs(12) XOR prbs(16) XOR prbs(17) XOR prbs(21);
					prbs(21) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(8) XOR prbs(13) XOR prbs(17) XOR prbs(18) XOR prbs(22);
					prbs(22) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(9) XOR prbs(14) XOR prbs(19);
					prbs(23) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(10) XOR prbs(15) XOR prbs(20);
					prbs(24) <= prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(11) XOR prbs(16) XOR prbs(21);
					prbs(25) <= prbs(3) XOR prbs(5) XOR prbs(7) XOR prbs(8) XOR prbs(12) XOR prbs(17) XOR prbs(22);
					prbs(26) <= prbs(0) XOR prbs(4) XOR prbs(6) XOR prbs(8) XOR prbs(9) XOR prbs(13);
					prbs(27) <= prbs(1) XOR prbs(5) XOR prbs(7) XOR prbs(9) XOR prbs(10) XOR prbs(14);
					prbs(28) <= prbs(2) XOR prbs(6) XOR prbs(8) XOR prbs(10) XOR prbs(11) XOR prbs(15);
					prbs(29) <= prbs(3) XOR prbs(7) XOR prbs(9) XOR prbs(11) XOR prbs(12) XOR prbs(16);
					prbs(30) <= prbs(4) XOR prbs(8) XOR prbs(10) XOR prbs(12) XOR prbs(13) XOR prbs(17);
					prbs(31) <= prbs(5) XOR prbs(9) XOR prbs(11) XOR prbs(13) XOR prbs(14) XOR prbs(18);
					prbs(32) <= prbs(6) XOR prbs(10) XOR prbs(12) XOR prbs(14) XOR prbs(15) XOR prbs(19);
					prbs(33) <= prbs(7) XOR prbs(11) XOR prbs(13) XOR prbs(15) XOR prbs(16) XOR prbs(20);
					prbs(34) <= prbs(8) XOR prbs(12) XOR prbs(14) XOR prbs(16) XOR prbs(17) XOR prbs(21);
					prbs(35) <= prbs(9) XOR prbs(13) XOR prbs(15) XOR prbs(17) XOR prbs(18) XOR prbs(22);
					prbs(36) <= prbs(0) XOR prbs(10) XOR prbs(14) XOR prbs(16) XOR prbs(19);
					prbs(37) <= prbs(1) XOR prbs(11) XOR prbs(15) XOR prbs(17) XOR prbs(20);
					prbs(38) <= prbs(2) XOR prbs(12) XOR prbs(16) XOR prbs(18) XOR prbs(21);
					prbs(39) <= prbs(3) XOR prbs(13) XOR prbs(17) XOR prbs(19) XOR prbs(22);
					prbs(40) <= prbs(0) XOR prbs(4) XOR prbs(14) XOR prbs(20);
					prbs(41) <= prbs(1) XOR prbs(5) XOR prbs(15) XOR prbs(21);
					prbs(42) <= prbs(2) XOR prbs(6) XOR prbs(16) XOR prbs(22);
					prbs(43) <= prbs(0) XOR prbs(3) XOR prbs(7) XOR prbs(17) XOR prbs(18);
					prbs(44) <= prbs(1) XOR prbs(4) XOR prbs(8) XOR prbs(18) XOR prbs(19);
					prbs(45) <= prbs(2) XOR prbs(5) XOR prbs(9) XOR prbs(19) XOR prbs(20);
					prbs(46) <= prbs(3) XOR prbs(6) XOR prbs(10) XOR prbs(20) XOR prbs(21);
					prbs(47) <= prbs(4) XOR prbs(7) XOR prbs(11) XOR prbs(21) XOR prbs(22);
					prbs(48) <= prbs(0) XOR prbs(5) XOR prbs(8) XOR prbs(12) XOR prbs(18) XOR prbs(22);
					prbs(49) <= prbs(0) XOR prbs(1) XOR prbs(6) XOR prbs(9) XOR prbs(13) XOR prbs(18) XOR prbs(19);
					prbs(50) <= prbs(1) XOR prbs(2) XOR prbs(7) XOR prbs(10) XOR prbs(14) XOR prbs(19) XOR prbs(20);
					prbs(51) <= prbs(2) XOR prbs(3) XOR prbs(8) XOR prbs(11) XOR prbs(15) XOR prbs(20) XOR prbs(21);
					prbs(52) <= prbs(3) XOR prbs(4) XOR prbs(9) XOR prbs(12) XOR prbs(16) XOR prbs(21) XOR prbs(22);
					prbs(53) <= prbs(0) XOR prbs(4) XOR prbs(5) XOR prbs(10) XOR prbs(13) XOR prbs(17) XOR prbs(18) XOR prbs(22);
					prbs(54) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(11) XOR prbs(14) XOR prbs(19);
					prbs(55) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(7) XOR prbs(12) XOR prbs(15) XOR prbs(20);
					prbs(56) <= prbs(2) XOR prbs(3) XOR prbs(7) XOR prbs(8) XOR prbs(13) XOR prbs(16) XOR prbs(21);
					prbs(57) <= prbs(3) XOR prbs(4) XOR prbs(8) XOR prbs(9) XOR prbs(14) XOR prbs(17) XOR prbs(22);
					prbs(58) <= prbs(0) XOR prbs(4) XOR prbs(5) XOR prbs(9) XOR prbs(10) XOR prbs(15);
					prbs(59) <= prbs(1) XOR prbs(5) XOR prbs(6) XOR prbs(10) XOR prbs(11) XOR prbs(16);
					prbs(60) <= prbs(2) XOR prbs(6) XOR prbs(7) XOR prbs(11) XOR prbs(12) XOR prbs(17);
					prbs(61) <= prbs(3) XOR prbs(7) XOR prbs(8) XOR prbs(12) XOR prbs(13) XOR prbs(18);
					prbs(62) <= prbs(4) XOR prbs(8) XOR prbs(9) XOR prbs(13) XOR prbs(14) XOR prbs(19);
					prbs(63) <= prbs(5) XOR prbs(9) XOR prbs(10) XOR prbs(14) XOR prbs(15) XOR prbs(20);
					prbs(64) <= prbs(6) XOR prbs(10) XOR prbs(11) XOR prbs(15) XOR prbs(16) XOR prbs(21);
					prbs(65) <= prbs(7) XOR prbs(11) XOR prbs(12) XOR prbs(16) XOR prbs(17) XOR prbs(22);
					prbs(66) <= prbs(0) XOR prbs(8) XOR prbs(12) XOR prbs(13) XOR prbs(17);
					prbs(67) <= prbs(1) XOR prbs(9) XOR prbs(13) XOR prbs(14) XOR prbs(18);
					prbs(68) <= prbs(2) XOR prbs(10) XOR prbs(14) XOR prbs(15) XOR prbs(19);
					prbs(69) <= prbs(3) XOR prbs(11) XOR prbs(15) XOR prbs(16) XOR prbs(20);
					prbs(70) <= prbs(4) XOR prbs(12) XOR prbs(16) XOR prbs(17) XOR prbs(21);
					prbs(71) <= prbs(5) XOR prbs(13) XOR prbs(17) XOR prbs(18) XOR prbs(22);
					prbs(72) <= prbs(0) XOR prbs(6) XOR prbs(14) XOR prbs(19);
					prbs(73) <= prbs(1) XOR prbs(7) XOR prbs(15) XOR prbs(20);
					prbs(74) <= prbs(2) XOR prbs(8) XOR prbs(16) XOR prbs(21);
					prbs(75) <= prbs(3) XOR prbs(9) XOR prbs(17) XOR prbs(22);
					prbs(76) <= prbs(0) XOR prbs(4) XOR prbs(10);
					prbs(77) <= prbs(1) XOR prbs(5) XOR prbs(11);
					prbs(78) <= prbs(2) XOR prbs(6) XOR prbs(12);
					prbs(79) <= prbs(3) XOR prbs(7) XOR prbs(13);
					prbs(80) <= prbs(4) XOR prbs(8) XOR prbs(14);
					prbs(81) <= prbs(5) XOR prbs(9) XOR prbs(15);
					prbs(82) <= prbs(6) XOR prbs(10) XOR prbs(16);
					prbs(83) <= prbs(7) XOR prbs(11) XOR prbs(17);
					prbs(84) <= prbs(8) XOR prbs(12) XOR prbs(18);
					prbs(85) <= prbs(9) XOR prbs(13) XOR prbs(19);
					prbs(86) <= prbs(10) XOR prbs(14) XOR prbs(20);
					prbs(87) <= prbs(11) XOR prbs(15) XOR prbs(21);
					prbs(88) <= prbs(12) XOR prbs(16) XOR prbs(22);
					prbs(89) <= prbs(0) XOR prbs(13) XOR prbs(17) XOR prbs(18);
					prbs(90) <= prbs(1) XOR prbs(14) XOR prbs(18) XOR prbs(19);
					prbs(91) <= prbs(2) XOR prbs(15) XOR prbs(19) XOR prbs(20);
					prbs(92) <= prbs(3) XOR prbs(16) XOR prbs(20) XOR prbs(21);
					prbs(93) <= prbs(4) XOR prbs(17) XOR prbs(21) XOR prbs(22);
					prbs(94) <= prbs(0) XOR prbs(5) XOR prbs(22);
					prbs(95) <= prbs(0) XOR prbs(1) XOR prbs(6) XOR prbs(18);
					prbs(96) <= prbs(1) XOR prbs(2) XOR prbs(7) XOR prbs(19);
					prbs(97) <= prbs(2) XOR prbs(3) XOR prbs(8) XOR prbs(20);
					prbs(98) <= prbs(3) XOR prbs(4) XOR prbs(9) XOR prbs(21);
					prbs(99) <= prbs(4) XOR prbs(5) XOR prbs(10) XOR prbs(22);
					prbs(100) <= prbs(0) XOR prbs(5) XOR prbs(6) XOR prbs(11) XOR prbs(18);
					prbs(101) <= prbs(1) XOR prbs(6) XOR prbs(7) XOR prbs(12) XOR prbs(19);
					prbs(102) <= prbs(2) XOR prbs(7) XOR prbs(8) XOR prbs(13) XOR prbs(20);
					prbs(103) <= prbs(3) XOR prbs(8) XOR prbs(9) XOR prbs(14) XOR prbs(21);
					prbs(104) <= prbs(4) XOR prbs(9) XOR prbs(10) XOR prbs(15) XOR prbs(22);
					prbs(105) <= prbs(0) XOR prbs(5) XOR prbs(10) XOR prbs(11) XOR prbs(16) XOR prbs(18);
					prbs(106) <= prbs(1) XOR prbs(6) XOR prbs(11) XOR prbs(12) XOR prbs(17) XOR prbs(19);
					prbs(107) <= prbs(2) XOR prbs(7) XOR prbs(12) XOR prbs(13) XOR prbs(18) XOR prbs(20);
					prbs(108) <= prbs(3) XOR prbs(8) XOR prbs(13) XOR prbs(14) XOR prbs(19) XOR prbs(21);
					prbs(109) <= prbs(4) XOR prbs(9) XOR prbs(14) XOR prbs(15) XOR prbs(20) XOR prbs(22);
					prbs(110) <= prbs(0) XOR prbs(5) XOR prbs(10) XOR prbs(15) XOR prbs(16) XOR prbs(18) XOR prbs(21);
					prbs(111) <= prbs(1) XOR prbs(6) XOR prbs(11) XOR prbs(16) XOR prbs(17) XOR prbs(19) XOR prbs(22);
					prbs(112) <= prbs(0) XOR prbs(2) XOR prbs(7) XOR prbs(12) XOR prbs(17) XOR prbs(20);
					prbs(113) <= prbs(1) XOR prbs(3) XOR prbs(8) XOR prbs(13) XOR prbs(18) XOR prbs(21);
					prbs(114) <= prbs(2) XOR prbs(4) XOR prbs(9) XOR prbs(14) XOR prbs(19) XOR prbs(22);
					prbs(115) <= prbs(0) XOR prbs(3) XOR prbs(5) XOR prbs(10) XOR prbs(15) XOR prbs(18) XOR prbs(20);
					prbs(116) <= prbs(1) XOR prbs(4) XOR prbs(6) XOR prbs(11) XOR prbs(16) XOR prbs(19) XOR prbs(21);
					prbs(117) <= prbs(2) XOR prbs(5) XOR prbs(7) XOR prbs(12) XOR prbs(17) XOR prbs(20) XOR prbs(22);
					prbs(118) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(8) XOR prbs(13) XOR prbs(21);
					prbs(119) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(9) XOR prbs(14) XOR prbs(22);
					prbs(120) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(10) XOR prbs(15) XOR prbs(18);
					prbs(121) <= prbs(1) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(11) XOR prbs(16) XOR prbs(19);
					prbs(122) <= prbs(2) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(12) XOR prbs(17) XOR prbs(20);
					prbs(123) <= prbs(3) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(13) XOR prbs(18) XOR prbs(21);
					prbs(124) <= prbs(4) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(14) XOR prbs(19) XOR prbs(22);
					prbs(125) <= prbs(0) XOR prbs(5) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(15) XOR prbs(18) XOR prbs(20);
					prbs(126) <= prbs(1) XOR prbs(6) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(16) XOR prbs(19) XOR prbs(21);
					prbs(127) <= prbs(2) XOR prbs(7) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(17) XOR prbs(20) XOR prbs(22);
					prbs(128) <= prbs(0) XOR prbs(3) XOR prbs(8) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(21);
					prbs(129) <= prbs(1) XOR prbs(4) XOR prbs(9) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(22);
					prbs(130) <= prbs(0) XOR prbs(2) XOR prbs(5) XOR prbs(10) XOR prbs(12) XOR prbs(15);
					prbs(131) <= prbs(1) XOR prbs(3) XOR prbs(6) XOR prbs(11) XOR prbs(13) XOR prbs(16);
					prbs(132) <= prbs(2) XOR prbs(4) XOR prbs(7) XOR prbs(12) XOR prbs(14) XOR prbs(17);
					prbs(133) <= prbs(3) XOR prbs(5) XOR prbs(8) XOR prbs(13) XOR prbs(15) XOR prbs(18);
					prbs(134) <= prbs(4) XOR prbs(6) XOR prbs(9) XOR prbs(14) XOR prbs(16) XOR prbs(19);
					prbs(135) <= prbs(5) XOR prbs(7) XOR prbs(10) XOR prbs(15) XOR prbs(17) XOR prbs(20);
					prbs(136) <= prbs(6) XOR prbs(8) XOR prbs(11) XOR prbs(16) XOR prbs(18) XOR prbs(21);
					prbs(137) <= prbs(7) XOR prbs(9) XOR prbs(12) XOR prbs(17) XOR prbs(19) XOR prbs(22);
					prbs(138) <= prbs(0) XOR prbs(8) XOR prbs(10) XOR prbs(13) XOR prbs(20);
					prbs(139) <= prbs(1) XOR prbs(9) XOR prbs(11) XOR prbs(14) XOR prbs(21);
					prbs(140) <= prbs(2) XOR prbs(10) XOR prbs(12) XOR prbs(15) XOR prbs(22);
					prbs(141) <= prbs(0) XOR prbs(3) XOR prbs(11) XOR prbs(13) XOR prbs(16) XOR prbs(18);
					prbs(142) <= prbs(1) XOR prbs(4) XOR prbs(12) XOR prbs(14) XOR prbs(17) XOR prbs(19);
					prbs(143) <= prbs(2) XOR prbs(5) XOR prbs(13) XOR prbs(15) XOR prbs(18) XOR prbs(20);
					prbs(144) <= prbs(3) XOR prbs(6) XOR prbs(14) XOR prbs(16) XOR prbs(19) XOR prbs(21);
					prbs(145) <= prbs(4) XOR prbs(7) XOR prbs(15) XOR prbs(17) XOR prbs(20) XOR prbs(22);
					prbs(146) <= prbs(0) XOR prbs(5) XOR prbs(8) XOR prbs(16) XOR prbs(21);
					prbs(147) <= prbs(1) XOR prbs(6) XOR prbs(9) XOR prbs(17) XOR prbs(22);
					prbs(148) <= prbs(0) XOR prbs(2) XOR prbs(7) XOR prbs(10);
					prbs(149) <= prbs(1) XOR prbs(3) XOR prbs(8) XOR prbs(11);
					prbs(150) <= prbs(2) XOR prbs(4) XOR prbs(9) XOR prbs(12);
					prbs(151) <= prbs(3) XOR prbs(5) XOR prbs(10) XOR prbs(13);
					prbs(152) <= prbs(4) XOR prbs(6) XOR prbs(11) XOR prbs(14);
					prbs(153) <= prbs(5) XOR prbs(7) XOR prbs(12) XOR prbs(15);
					prbs(154) <= prbs(6) XOR prbs(8) XOR prbs(13) XOR prbs(16);
					prbs(155) <= prbs(7) XOR prbs(9) XOR prbs(14) XOR prbs(17);
					prbs(156) <= prbs(8) XOR prbs(10) XOR prbs(15) XOR prbs(18);
					prbs(157) <= prbs(9) XOR prbs(11) XOR prbs(16) XOR prbs(19);
					prbs(158) <= prbs(10) XOR prbs(12) XOR prbs(17) XOR prbs(20);
					prbs(159) <= prbs(11) XOR prbs(13) XOR prbs(18) XOR prbs(21);
					prbs(160) <= prbs(12) XOR prbs(14) XOR prbs(19) XOR prbs(22);
					prbs(161) <= prbs(0) XOR prbs(13) XOR prbs(15) XOR prbs(18) XOR prbs(20);
					prbs(162) <= prbs(1) XOR prbs(14) XOR prbs(16) XOR prbs(19) XOR prbs(21);
					prbs(163) <= prbs(2) XOR prbs(15) XOR prbs(17) XOR prbs(20) XOR prbs(22);
					prbs(164) <= prbs(0) XOR prbs(3) XOR prbs(16) XOR prbs(21);
					prbs(165) <= prbs(1) XOR prbs(4) XOR prbs(17) XOR prbs(22);
					prbs(166) <= prbs(0) XOR prbs(2) XOR prbs(5);
					prbs(167) <= prbs(1) XOR prbs(3) XOR prbs(6);
					prbs(168) <= prbs(2) XOR prbs(4) XOR prbs(7);
					prbs(169) <= prbs(3) XOR prbs(5) XOR prbs(8);
					prbs(170) <= prbs(4) XOR prbs(6) XOR prbs(9);
					prbs(171) <= prbs(5) XOR prbs(7) XOR prbs(10);
					prbs(172) <= prbs(6) XOR prbs(8) XOR prbs(11);
					prbs(173) <= prbs(7) XOR prbs(9) XOR prbs(12);
					prbs(174) <= prbs(8) XOR prbs(10) XOR prbs(13);
					prbs(175) <= prbs(9) XOR prbs(11) XOR prbs(14);
					prbs(176) <= prbs(10) XOR prbs(12) XOR prbs(15);
					prbs(177) <= prbs(11) XOR prbs(13) XOR prbs(16);
					prbs(178) <= prbs(12) XOR prbs(14) XOR prbs(17);
					prbs(179) <= prbs(13) XOR prbs(15) XOR prbs(18);
					prbs(180) <= prbs(14) XOR prbs(16) XOR prbs(19);
					prbs(181) <= prbs(15) XOR prbs(17) XOR prbs(20);
					prbs(182) <= prbs(16) XOR prbs(18) XOR prbs(21);
					prbs(183) <= prbs(17) XOR prbs(19) XOR prbs(22);
					prbs(184) <= prbs(0) XOR prbs(20);
					prbs(185) <= prbs(1) XOR prbs(21);
					prbs(186) <= prbs(2) XOR prbs(22);
					prbs(187) <= prbs(0) XOR prbs(3) XOR prbs(18);
					prbs(188) <= prbs(1) XOR prbs(4) XOR prbs(19);
					prbs(189) <= prbs(2) XOR prbs(5) XOR prbs(20);
					prbs(190) <= prbs(3) XOR prbs(6) XOR prbs(21);
					prbs(191) <= prbs(4) XOR prbs(7) XOR prbs(22);
					prbs(192) <= prbs(0) XOR prbs(5) XOR prbs(8) XOR prbs(18);
					prbs(193) <= prbs(1) XOR prbs(6) XOR prbs(9) XOR prbs(19);
					prbs(194) <= prbs(2) XOR prbs(7) XOR prbs(10) XOR prbs(20);
					prbs(195) <= prbs(3) XOR prbs(8) XOR prbs(11) XOR prbs(21);
					prbs(196) <= prbs(4) XOR prbs(9) XOR prbs(12) XOR prbs(22);
					prbs(197) <= prbs(0) XOR prbs(5) XOR prbs(10) XOR prbs(13) XOR prbs(18);
					prbs(198) <= prbs(1) XOR prbs(6) XOR prbs(11) XOR prbs(14) XOR prbs(19);
					prbs(199) <= prbs(2) XOR prbs(7) XOR prbs(12) XOR prbs(15) XOR prbs(20);
					prbs(200) <= prbs(3) XOR prbs(8) XOR prbs(13) XOR prbs(16) XOR prbs(21);
					prbs(201) <= prbs(4) XOR prbs(9) XOR prbs(14) XOR prbs(17) XOR prbs(22);
					prbs(202) <= prbs(0) XOR prbs(5) XOR prbs(10) XOR prbs(15);
					prbs(203) <= prbs(1) XOR prbs(6) XOR prbs(11) XOR prbs(16);
					prbs(204) <= prbs(2) XOR prbs(7) XOR prbs(12) XOR prbs(17);
					prbs(205) <= prbs(3) XOR prbs(8) XOR prbs(13) XOR prbs(18);
					prbs(206) <= prbs(4) XOR prbs(9) XOR prbs(14) XOR prbs(19);
					prbs(207) <= prbs(5) XOR prbs(10) XOR prbs(15) XOR prbs(20);
					prbs(208) <= prbs(6) XOR prbs(11) XOR prbs(16) XOR prbs(21);
					prbs(209) <= prbs(7) XOR prbs(12) XOR prbs(17) XOR prbs(22);
					prbs(210) <= prbs(0) XOR prbs(8) XOR prbs(13);
					prbs(211) <= prbs(1) XOR prbs(9) XOR prbs(14);
					prbs(212) <= prbs(2) XOR prbs(10) XOR prbs(15);
					prbs(213) <= prbs(3) XOR prbs(11) XOR prbs(16);
					prbs(214) <= prbs(4) XOR prbs(12) XOR prbs(17);
					prbs(215) <= prbs(5) XOR prbs(13) XOR prbs(18);
					prbs(216) <= prbs(6) XOR prbs(14) XOR prbs(19);
					prbs(217) <= prbs(7) XOR prbs(15) XOR prbs(20);
					prbs(218) <= prbs(8) XOR prbs(16) XOR prbs(21);
					prbs(219) <= prbs(9) XOR prbs(17) XOR prbs(22);
					prbs(220) <= prbs(0) XOR prbs(10);
					prbs(221) <= prbs(1) XOR prbs(11);
					prbs(222) <= prbs(2) XOR prbs(12);
					prbs(223) <= prbs(3) XOR prbs(13);
					prbs(224) <= prbs(4) XOR prbs(14);
					prbs(225) <= prbs(5) XOR prbs(15);
					prbs(226) <= prbs(6) XOR prbs(16);
					prbs(227) <= prbs(7) XOR prbs(17);
					prbs(228) <= prbs(8) XOR prbs(18);
					prbs(229) <= prbs(9) XOR prbs(19);
					prbs(230) <= prbs(10) XOR prbs(20);
					prbs(231) <= prbs(11) XOR prbs(21);
					prbs(232) <= prbs(12) XOR prbs(22);
					prbs(233) <= prbs(0) XOR prbs(13) XOR prbs(18);
					prbs(234) <= prbs(1) XOR prbs(14) XOR prbs(19);
					prbs(235) <= prbs(2) XOR prbs(15) XOR prbs(20);
					prbs(236) <= prbs(3) XOR prbs(16) XOR prbs(21);
					prbs(237) <= prbs(4) XOR prbs(17) XOR prbs(22);
					prbs(238) <= prbs(0) XOR prbs(5);
					prbs(239) <= prbs(1) XOR prbs(6);
					prbs(240) <= prbs(2) XOR prbs(7);
					prbs(241) <= prbs(3) XOR prbs(8);
					prbs(242) <= prbs(4) XOR prbs(9);
					prbs(243) <= prbs(5) XOR prbs(10);
					prbs(244) <= prbs(6) XOR prbs(11);
					prbs(245) <= prbs(7) XOR prbs(12);
					prbs(246) <= prbs(8) XOR prbs(13);
					prbs(247) <= prbs(9) XOR prbs(14);
					prbs(248) <= prbs(10) XOR prbs(15);
					prbs(249) <= prbs(11) XOR prbs(16);
					prbs(250) <= prbs(12) XOR prbs(17);
					prbs(251) <= prbs(13) XOR prbs(18);
					prbs(252) <= prbs(14) XOR prbs(19);
					prbs(253) <= prbs(15) XOR prbs(20);
					prbs(254) <= prbs(16) XOR prbs(21);
					prbs(255) <= prbs(17) XOR prbs(22);

	
					
				WHEN "10"	=>  -- PRBS 2^31-1 [31,28] (parallel 256bit serializer)
				
					prbs(0) <= prbs(20) XOR prbs(23) XOR prbs(24) XOR prbs(30);
					prbs(1) <= prbs(0) XOR prbs(21) XOR prbs(24) XOR prbs(25) XOR prbs(28);
					prbs(2) <= prbs(1) XOR prbs(22) XOR prbs(25) XOR prbs(26) XOR prbs(29);
					prbs(3) <= prbs(2) XOR prbs(23) XOR prbs(26) XOR prbs(27) XOR prbs(30);
					prbs(4) <= prbs(0) XOR prbs(3) XOR prbs(24) XOR prbs(27);
					prbs(5) <= prbs(1) XOR prbs(4) XOR prbs(25) XOR prbs(28);
					prbs(6) <= prbs(2) XOR prbs(5) XOR prbs(26) XOR prbs(29);
					prbs(7) <= prbs(3) XOR prbs(6) XOR prbs(27) XOR prbs(30);
					prbs(8) <= prbs(0) XOR prbs(4) XOR prbs(7);
					prbs(9) <= prbs(1) XOR prbs(5) XOR prbs(8);
					prbs(10) <= prbs(2) XOR prbs(6) XOR prbs(9);
					prbs(11) <= prbs(3) XOR prbs(7) XOR prbs(10);
					prbs(12) <= prbs(4) XOR prbs(8) XOR prbs(11);
					prbs(13) <= prbs(5) XOR prbs(9) XOR prbs(12);
					prbs(14) <= prbs(6) XOR prbs(10) XOR prbs(13);
					prbs(15) <= prbs(7) XOR prbs(11) XOR prbs(14);
					prbs(16) <= prbs(8) XOR prbs(12) XOR prbs(15);
					prbs(17) <= prbs(9) XOR prbs(13) XOR prbs(16);
					prbs(18) <= prbs(10) XOR prbs(14) XOR prbs(17);
					prbs(19) <= prbs(11) XOR prbs(15) XOR prbs(18);
					prbs(20) <= prbs(12) XOR prbs(16) XOR prbs(19);
					prbs(21) <= prbs(13) XOR prbs(17) XOR prbs(20);
					prbs(22) <= prbs(14) XOR prbs(18) XOR prbs(21);
					prbs(23) <= prbs(15) XOR prbs(19) XOR prbs(22);
					prbs(24) <= prbs(16) XOR prbs(20) XOR prbs(23);
					prbs(25) <= prbs(17) XOR prbs(21) XOR prbs(24);
					prbs(26) <= prbs(18) XOR prbs(22) XOR prbs(25);
					prbs(27) <= prbs(19) XOR prbs(23) XOR prbs(26);
					prbs(28) <= prbs(20) XOR prbs(24) XOR prbs(27);
					prbs(29) <= prbs(21) XOR prbs(25) XOR prbs(28);
					prbs(30) <= prbs(22) XOR prbs(26) XOR prbs(29);
					prbs(31) <= prbs(23) XOR prbs(27) XOR prbs(30);
					prbs(32) <= prbs(0) XOR prbs(24);
					prbs(33) <= prbs(1) XOR prbs(25);
					prbs(34) <= prbs(2) XOR prbs(26);
					prbs(35) <= prbs(3) XOR prbs(27);
					prbs(36) <= prbs(4) XOR prbs(28);
					prbs(37) <= prbs(5) XOR prbs(29);
					prbs(38) <= prbs(6) XOR prbs(30);
					prbs(39) <= prbs(0) XOR prbs(7) XOR prbs(28);
					prbs(40) <= prbs(1) XOR prbs(8) XOR prbs(29);
					prbs(41) <= prbs(2) XOR prbs(9) XOR prbs(30);
					prbs(42) <= prbs(0) XOR prbs(3) XOR prbs(10) XOR prbs(28);
					prbs(43) <= prbs(1) XOR prbs(4) XOR prbs(11) XOR prbs(29);
					prbs(44) <= prbs(2) XOR prbs(5) XOR prbs(12) XOR prbs(30);
					prbs(45) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(13) XOR prbs(28);
					prbs(46) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(14) XOR prbs(29);
					prbs(47) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(15) XOR prbs(30);
					prbs(48) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(16) XOR prbs(28);
					prbs(49) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(17) XOR prbs(29);
					prbs(50) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(18) XOR prbs(30);
					prbs(51) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(19) XOR prbs(28);
					prbs(52) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(20) XOR prbs(29);
					prbs(53) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(21) XOR prbs(30);
					prbs(54) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(22) XOR prbs(28);
					prbs(55) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(23) XOR prbs(29);
					prbs(56) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(24) XOR prbs(30);
					prbs(57) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(25) XOR prbs(28);
					prbs(58) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(26) XOR prbs(29);
					prbs(59) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(27) XOR prbs(30);
					prbs(60) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21);
					prbs(61) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22);
					prbs(62) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23);
					prbs(63) <= prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24);
					prbs(64) <= prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25);
					prbs(65) <= prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26);
					prbs(66) <= prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27);
					prbs(67) <= prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25) XOR prbs(28);
					prbs(68) <= prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26) XOR prbs(29);
					prbs(69) <= prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27) XOR prbs(30);
					prbs(70) <= prbs(0) XOR prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25);
					prbs(71) <= prbs(1) XOR prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26);
					prbs(72) <= prbs(2) XOR prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27);
					prbs(73) <= prbs(3) XOR prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25) XOR prbs(28);
					prbs(74) <= prbs(4) XOR prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26) XOR prbs(29);
					prbs(75) <= prbs(5) XOR prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27) XOR prbs(30);
					prbs(76) <= prbs(0) XOR prbs(6) XOR prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25);
					prbs(77) <= prbs(1) XOR prbs(7) XOR prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26);
					prbs(78) <= prbs(2) XOR prbs(8) XOR prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27);
					prbs(79) <= prbs(3) XOR prbs(9) XOR prbs(19) XOR prbs(22) XOR prbs(25) XOR prbs(28);
					prbs(80) <= prbs(4) XOR prbs(10) XOR prbs(20) XOR prbs(23) XOR prbs(26) XOR prbs(29);
					prbs(81) <= prbs(5) XOR prbs(11) XOR prbs(21) XOR prbs(24) XOR prbs(27) XOR prbs(30);
					prbs(82) <= prbs(0) XOR prbs(6) XOR prbs(12) XOR prbs(22) XOR prbs(25);
					prbs(83) <= prbs(1) XOR prbs(7) XOR prbs(13) XOR prbs(23) XOR prbs(26);
					prbs(84) <= prbs(2) XOR prbs(8) XOR prbs(14) XOR prbs(24) XOR prbs(27);
					prbs(85) <= prbs(3) XOR prbs(9) XOR prbs(15) XOR prbs(25) XOR prbs(28);
					prbs(86) <= prbs(4) XOR prbs(10) XOR prbs(16) XOR prbs(26) XOR prbs(29);
					prbs(87) <= prbs(5) XOR prbs(11) XOR prbs(17) XOR prbs(27) XOR prbs(30);
					prbs(88) <= prbs(0) XOR prbs(6) XOR prbs(12) XOR prbs(18);
					prbs(89) <= prbs(1) XOR prbs(7) XOR prbs(13) XOR prbs(19);
					prbs(90) <= prbs(2) XOR prbs(8) XOR prbs(14) XOR prbs(20);
					prbs(91) <= prbs(3) XOR prbs(9) XOR prbs(15) XOR prbs(21);
					prbs(92) <= prbs(4) XOR prbs(10) XOR prbs(16) XOR prbs(22);
					prbs(93) <= prbs(5) XOR prbs(11) XOR prbs(17) XOR prbs(23);
					prbs(94) <= prbs(6) XOR prbs(12) XOR prbs(18) XOR prbs(24);
					prbs(95) <= prbs(7) XOR prbs(13) XOR prbs(19) XOR prbs(25);
					prbs(96) <= prbs(8) XOR prbs(14) XOR prbs(20) XOR prbs(26);
					prbs(97) <= prbs(9) XOR prbs(15) XOR prbs(21) XOR prbs(27);
					prbs(98) <= prbs(10) XOR prbs(16) XOR prbs(22) XOR prbs(28);
					prbs(99) <= prbs(11) XOR prbs(17) XOR prbs(23) XOR prbs(29);
					prbs(100) <= prbs(12) XOR prbs(18) XOR prbs(24) XOR prbs(30);
					prbs(101) <= prbs(0) XOR prbs(13) XOR prbs(19) XOR prbs(25) XOR prbs(28);
					prbs(102) <= prbs(1) XOR prbs(14) XOR prbs(20) XOR prbs(26) XOR prbs(29);
					prbs(103) <= prbs(2) XOR prbs(15) XOR prbs(21) XOR prbs(27) XOR prbs(30);
					prbs(104) <= prbs(0) XOR prbs(3) XOR prbs(16) XOR prbs(22);
					prbs(105) <= prbs(1) XOR prbs(4) XOR prbs(17) XOR prbs(23);
					prbs(106) <= prbs(2) XOR prbs(5) XOR prbs(18) XOR prbs(24);
					prbs(107) <= prbs(3) XOR prbs(6) XOR prbs(19) XOR prbs(25);
					prbs(108) <= prbs(4) XOR prbs(7) XOR prbs(20) XOR prbs(26);
					prbs(109) <= prbs(5) XOR prbs(8) XOR prbs(21) XOR prbs(27);
					prbs(110) <= prbs(6) XOR prbs(9) XOR prbs(22) XOR prbs(28);
					prbs(111) <= prbs(7) XOR prbs(10) XOR prbs(23) XOR prbs(29);
					prbs(112) <= prbs(8) XOR prbs(11) XOR prbs(24) XOR prbs(30);
					prbs(113) <= prbs(0) XOR prbs(9) XOR prbs(12) XOR prbs(25) XOR prbs(28);
					prbs(114) <= prbs(1) XOR prbs(10) XOR prbs(13) XOR prbs(26) XOR prbs(29);
					prbs(115) <= prbs(2) XOR prbs(11) XOR prbs(14) XOR prbs(27) XOR prbs(30);
					prbs(116) <= prbs(0) XOR prbs(3) XOR prbs(12) XOR prbs(15);
					prbs(117) <= prbs(1) XOR prbs(4) XOR prbs(13) XOR prbs(16);
					prbs(118) <= prbs(2) XOR prbs(5) XOR prbs(14) XOR prbs(17);
					prbs(119) <= prbs(3) XOR prbs(6) XOR prbs(15) XOR prbs(18);
					prbs(120) <= prbs(4) XOR prbs(7) XOR prbs(16) XOR prbs(19);
					prbs(121) <= prbs(5) XOR prbs(8) XOR prbs(17) XOR prbs(20);
					prbs(122) <= prbs(6) XOR prbs(9) XOR prbs(18) XOR prbs(21);
					prbs(123) <= prbs(7) XOR prbs(10) XOR prbs(19) XOR prbs(22);
					prbs(124) <= prbs(8) XOR prbs(11) XOR prbs(20) XOR prbs(23);
					prbs(125) <= prbs(9) XOR prbs(12) XOR prbs(21) XOR prbs(24);
					prbs(126) <= prbs(10) XOR prbs(13) XOR prbs(22) XOR prbs(25);
					prbs(127) <= prbs(11) XOR prbs(14) XOR prbs(23) XOR prbs(26);
					prbs(128) <= prbs(12) XOR prbs(15) XOR prbs(24) XOR prbs(27);
					prbs(129) <= prbs(13) XOR prbs(16) XOR prbs(25) XOR prbs(28);
					prbs(130) <= prbs(14) XOR prbs(17) XOR prbs(26) XOR prbs(29);
					prbs(131) <= prbs(15) XOR prbs(18) XOR prbs(27) XOR prbs(30);
					prbs(132) <= prbs(0) XOR prbs(16) XOR prbs(19);
					prbs(133) <= prbs(1) XOR prbs(17) XOR prbs(20);
					prbs(134) <= prbs(2) XOR prbs(18) XOR prbs(21);
					prbs(135) <= prbs(3) XOR prbs(19) XOR prbs(22);
					prbs(136) <= prbs(4) XOR prbs(20) XOR prbs(23);
					prbs(137) <= prbs(5) XOR prbs(21) XOR prbs(24);
					prbs(138) <= prbs(6) XOR prbs(22) XOR prbs(25);
					prbs(139) <= prbs(7) XOR prbs(23) XOR prbs(26);
					prbs(140) <= prbs(8) XOR prbs(24) XOR prbs(27);
					prbs(141) <= prbs(9) XOR prbs(25) XOR prbs(28);
					prbs(142) <= prbs(10) XOR prbs(26) XOR prbs(29);
					prbs(143) <= prbs(11) XOR prbs(27) XOR prbs(30);
					prbs(144) <= prbs(0) XOR prbs(12);
					prbs(145) <= prbs(1) XOR prbs(13);
					prbs(146) <= prbs(2) XOR prbs(14);
					prbs(147) <= prbs(3) XOR prbs(15);
					prbs(148) <= prbs(4) XOR prbs(16);
					prbs(149) <= prbs(5) XOR prbs(17);
					prbs(150) <= prbs(6) XOR prbs(18);
					prbs(151) <= prbs(7) XOR prbs(19);
					prbs(152) <= prbs(8) XOR prbs(20);
					prbs(153) <= prbs(9) XOR prbs(21);
					prbs(154) <= prbs(10) XOR prbs(22);
					prbs(155) <= prbs(11) XOR prbs(23);
					prbs(156) <= prbs(12) XOR prbs(24);
					prbs(157) <= prbs(13) XOR prbs(25);
					prbs(158) <= prbs(14) XOR prbs(26);
					prbs(159) <= prbs(15) XOR prbs(27);
					prbs(160) <= prbs(16) XOR prbs(28);
					prbs(161) <= prbs(17) XOR prbs(29);
					prbs(162) <= prbs(18) XOR prbs(30);
					prbs(163) <= prbs(0) XOR prbs(19) XOR prbs(28);
					prbs(164) <= prbs(1) XOR prbs(20) XOR prbs(29);
					prbs(165) <= prbs(2) XOR prbs(21) XOR prbs(30);
					prbs(166) <= prbs(0) XOR prbs(3) XOR prbs(22) XOR prbs(28);
					prbs(167) <= prbs(1) XOR prbs(4) XOR prbs(23) XOR prbs(29);
					prbs(168) <= prbs(2) XOR prbs(5) XOR prbs(24) XOR prbs(30);
					prbs(169) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(25) XOR prbs(28);
					prbs(170) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(26) XOR prbs(29);
					prbs(171) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(27) XOR prbs(30);
					prbs(172) <= prbs(0) XOR prbs(3) XOR prbs(6) XOR prbs(9);
					prbs(173) <= prbs(1) XOR prbs(4) XOR prbs(7) XOR prbs(10);
					prbs(174) <= prbs(2) XOR prbs(5) XOR prbs(8) XOR prbs(11);
					prbs(175) <= prbs(3) XOR prbs(6) XOR prbs(9) XOR prbs(12);
					prbs(176) <= prbs(4) XOR prbs(7) XOR prbs(10) XOR prbs(13);
					prbs(177) <= prbs(5) XOR prbs(8) XOR prbs(11) XOR prbs(14);
					prbs(178) <= prbs(6) XOR prbs(9) XOR prbs(12) XOR prbs(15);
					prbs(179) <= prbs(7) XOR prbs(10) XOR prbs(13) XOR prbs(16);
					prbs(180) <= prbs(8) XOR prbs(11) XOR prbs(14) XOR prbs(17);
					prbs(181) <= prbs(9) XOR prbs(12) XOR prbs(15) XOR prbs(18);
					prbs(182) <= prbs(10) XOR prbs(13) XOR prbs(16) XOR prbs(19);
					prbs(183) <= prbs(11) XOR prbs(14) XOR prbs(17) XOR prbs(20);
					prbs(184) <= prbs(12) XOR prbs(15) XOR prbs(18) XOR prbs(21);
					prbs(185) <= prbs(13) XOR prbs(16) XOR prbs(19) XOR prbs(22);
					prbs(186) <= prbs(14) XOR prbs(17) XOR prbs(20) XOR prbs(23);
					prbs(187) <= prbs(15) XOR prbs(18) XOR prbs(21) XOR prbs(24);
					prbs(188) <= prbs(16) XOR prbs(19) XOR prbs(22) XOR prbs(25);
					prbs(189) <= prbs(17) XOR prbs(20) XOR prbs(23) XOR prbs(26);
					prbs(190) <= prbs(18) XOR prbs(21) XOR prbs(24) XOR prbs(27);
					prbs(191) <= prbs(19) XOR prbs(22) XOR prbs(25) XOR prbs(28);
					prbs(192) <= prbs(20) XOR prbs(23) XOR prbs(26) XOR prbs(29);
					prbs(193) <= prbs(21) XOR prbs(24) XOR prbs(27) XOR prbs(30);
					prbs(194) <= prbs(0) XOR prbs(22) XOR prbs(25);
					prbs(195) <= prbs(1) XOR prbs(23) XOR prbs(26);
					prbs(196) <= prbs(2) XOR prbs(24) XOR prbs(27);
					prbs(197) <= prbs(3) XOR prbs(25) XOR prbs(28);
					prbs(198) <= prbs(4) XOR prbs(26) XOR prbs(29);
					prbs(199) <= prbs(5) XOR prbs(27) XOR prbs(30);
					prbs(200) <= prbs(0) XOR prbs(6);
					prbs(201) <= prbs(1) XOR prbs(7);
					prbs(202) <= prbs(2) XOR prbs(8);
					prbs(203) <= prbs(3) XOR prbs(9);
					prbs(204) <= prbs(4) XOR prbs(10);
					prbs(205) <= prbs(5) XOR prbs(11);
					prbs(206) <= prbs(6) XOR prbs(12);
					prbs(207) <= prbs(7) XOR prbs(13);
					prbs(208) <= prbs(8) XOR prbs(14);
					prbs(209) <= prbs(9) XOR prbs(15);
					prbs(210) <= prbs(10) XOR prbs(16);
					prbs(211) <= prbs(11) XOR prbs(17);
					prbs(212) <= prbs(12) XOR prbs(18);
					prbs(213) <= prbs(13) XOR prbs(19);
					prbs(214) <= prbs(14) XOR prbs(20);
					prbs(215) <= prbs(15) XOR prbs(21);
					prbs(216) <= prbs(16) XOR prbs(22);
					prbs(217) <= prbs(17) XOR prbs(23);
					prbs(218) <= prbs(18) XOR prbs(24);
					prbs(219) <= prbs(19) XOR prbs(25);
					prbs(220) <= prbs(20) XOR prbs(26);
					prbs(221) <= prbs(21) XOR prbs(27);
					prbs(222) <= prbs(22) XOR prbs(28);
					prbs(223) <= prbs(23) XOR prbs(29);
					prbs(224) <= prbs(24) XOR prbs(30);
					prbs(225) <= prbs(0) XOR prbs(25) XOR prbs(28);
					prbs(226) <= prbs(1) XOR prbs(26) XOR prbs(29);
					prbs(227) <= prbs(2) XOR prbs(27) XOR prbs(30);
					prbs(228) <= prbs(0) XOR prbs(3);
					prbs(229) <= prbs(1) XOR prbs(4);
					prbs(230) <= prbs(2) XOR prbs(5);
					prbs(231) <= prbs(3) XOR prbs(6);
					prbs(232) <= prbs(4) XOR prbs(7);
					prbs(233) <= prbs(5) XOR prbs(8);
					prbs(234) <= prbs(6) XOR prbs(9);
					prbs(235) <= prbs(7) XOR prbs(10);
					prbs(236) <= prbs(8) XOR prbs(11);
					prbs(237) <= prbs(9) XOR prbs(12);
					prbs(238) <= prbs(10) XOR prbs(13);
					prbs(239) <= prbs(11) XOR prbs(14);
					prbs(240) <= prbs(12) XOR prbs(15);
					prbs(241) <= prbs(13) XOR prbs(16);
					prbs(242) <= prbs(14) XOR prbs(17);
					prbs(243) <= prbs(15) XOR prbs(18);
					prbs(244) <= prbs(16) XOR prbs(19);
					prbs(245) <= prbs(17) XOR prbs(20);
					prbs(246) <= prbs(18) XOR prbs(21);
					prbs(247) <= prbs(19) XOR prbs(22);
					prbs(248) <= prbs(20) XOR prbs(23);
					prbs(249) <= prbs(21) XOR prbs(24);
					prbs(250) <= prbs(22) XOR prbs(25);
					prbs(251) <= prbs(23) XOR prbs(26);
					prbs(252) <= prbs(24) XOR prbs(27);
					prbs(253) <= prbs(25) XOR prbs(28);
					prbs(254) <= prbs(26) XOR prbs(29);
					prbs(255) <= prbs(27) XOR prbs(30);

					
				WHEN "11"  => -- Clock pattern
					
					--prbs(127 downto 0)	<= X"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
					--prbs(127 downto 0)	<= X"AAFF00AAAAAAAAAAAAAAAAAAAAAAAAAA";	
					-- counter pattern 
					--prbs <= X"0123456789ABCDEF00000000FFFFFFFF";
					prbs	<= X"0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F";
				WHEN OTHERS => NULL;

				END CASE;
			end if; -- Enable
		  end if;
		end if;
	end process;

process(coreclk)
	begin
	if rising_edge(coreclk) then
		if (Reset_dupA2 = '1') then
				tx_data <= X"0707070707070707070707070707070707070707070707070707070707070707";
				Valid_min1 <= '0';

				detect_inserterror <= '0';	
				count_deskew <= (OTHERS => '0');
				deskew_pulse <= '0';
				delayed_error <= '0';
				inserterror_q <= '0';

		else

				

				inserterror_q <= inserterror_synchro;

				
				-- Generate deskew pulse
				
				if (count_deskew = "11") then
					deskew_pulse <= '1';
					count_deskew <= (OTHERS => '0');
				else
					deskew_pulse <= '0';
					count_deskew <= count_deskew + 1;
				end if;
				
				if (inserterror_q /= inserterror_synchro) and (inserterror_synchro = '1') then
					detect_inserterror <= '1';
				else
					detect_inserterror <= '0';
				end if;
				
			if Enable = '1' then 
					--CountPattern <= CountPattern + 1;

					if delayed_error = '1' then
						delayed_error <= '0';
					end if;	
				if detect_inserterror = '1' or delayed_error = '1' then 
					report "==========================================================================================================> Inserted one bit error in Tx data ..." severity note;
					tx_data <= (not prbs(255)) & prbs(254 downto 0);			-- insert One biterror
					--tx_data <= (not prbs(255 downto 250) & prbs(249 downto 0) );			-- insert 6 biterrors	
					--tx_data <= (not prbs(255 downto 128) & prbs(127 downto 0) );			-- insert 128 biterrors	
					--tx_data <= (not prbs(255 downto 127) & prbs(126 downto 0) );			-- insert 129 biterrors	
					--tx_data <= (not prbs(255 downto 1) & prbs(0) );			-- insert 255 biterrors	
					--tx_data <= (not prbs(255 downto 0));			-- insert 256 biterrors	
				else
					tx_data <= prbs(255 downto 0);
					--tx_data <= tx_data + 1;
				end if;
				Valid_min1 <= '1';
			else
					if detect_inserterror = '1' then
						delayed_error <= '1';
					end if;					
					tx_data <= X"0707070707070707070707070707070707070707070707070707070707070707";
					Valid_min1 <= '0';
			end if;

		
		end if;
		end if;
	end process;
	
	process(coreclk)
	begin
		if rising_edge(coreclk) then		
			SwapMSB_With_LSB:
			FOR i IN 0 to 255 LOOP
				tx_data_sig(i) <= tx_data(255-i);
			END LOOP SwapMSB_With_LSB;		
			
		

		 Valid <= Valid_min1;	
		
		end if;
	end process;
	
Prbsout <= tx_data_sig;

		
			
end;


