library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;

entity multi_prbsgenerate_32bit is
GENERIC
	(
		INVERT_POLARITY_PRBS			:  boolean := true  -- For L/H tile set to true, For E-tile set to false (allows compatibility with Hard PRBS generators/checkers)
	);
PORT(
	coreclk  	: in std_logic;
	Enable		: in std_logic;
	StartValue	: in std_logic_vector(31 downto 0);
	Reset	 	: in std_logic;
	PrbsSelect	: in std_logic_vector(2 downto 0);
	Inserterror : in std_logic;
	Prbsout 	: out std_logic_vector(31 downto 0);
	Valid		: out std_logic
	);
END multi_prbsgenerate_32bit;	


architecture rtl of multi_prbsgenerate_32bit is


component Synchro is
port
	(
	Clk			: in std_logic;
	data_in		: in std_logic;
	data_out		: out std_logic
	);
end component;
signal prbs 			: std_logic_vector(31 downto 0);
signal tx_data 			: std_logic_vector(31 downto 0);
signal tx_data_sig 		: std_logic_vector(31 downto 0) := (OTHERS => '0');
signal detect_inserterror	: std_logic;
signal delayed_error    : std_logic;
signal inserterror_Q	: std_logic;
signal inserterror_synchro	: std_logic;


signal count				: std_logic_vector(5 downto 0);
signal PrbsSelect_s1, PrbsSelect_s2, PrbsSelect_s3 : std_logic_vector(2 downto 0); 

signal Reset_dupA1, Reset_dupA2 :  std_logic :='0';
attribute preserve_syn_only : boolean;
attribute preserve_syn_only of Reset_dupA1 : signal is true;

signal Valid_min1 		: std_logic;

begin

	
Synchro_inst : Synchro
port map(
Clk 			=> coreclk,
data_in 		=> inserterror,
data_out 	=> inserterror_synchro
);

	process(coreclk)
	begin
		if rising_edge(coreclk) then
				Reset_dupA1 <= Reset;
				Reset_dupA2 <= Reset_dupA1;		
				
			if (Reset_dupA2 = '1') then
				prbs <= StartValue;
				count <= (OTHERS => '0');
				PrbsSelect_s1 <= (OTHERS => '0'); 
				PrbsSelect_s2 <= (OTHERS => '0'); 
				PrbsSelect_s3 <= (OTHERS => '0'); 						
			else
				PrbsSelect_s1 <= PrbsSelect; 
				PrbsSelect_s2 <= PrbsSelect_s1; 
				PrbsSelect_s3 <= PrbsSelect_s2; 
				
			if Enable = '1' then
			CASE PrbsSelect_s3 IS
				WHEN "000" =>		-- PRBS 2^7-1 (parallel 32bit serializer) (T[7,6]) 
					-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
					-- (compatible with E tile Hard Prbs (with polarity inversion off))		

					prbs(0) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(6);
					prbs(1) <= prbs(0) XOR prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6);
					prbs(2) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(5);
					prbs(3) <= prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6);
					prbs(4) <= prbs(0) XOR prbs(2) XOR prbs(3);
					prbs(5) <= prbs(1) XOR prbs(3) XOR prbs(4);
					prbs(6) <= prbs(2) XOR prbs(4) XOR prbs(5);
					prbs(7) <= prbs(3) XOR prbs(5) XOR prbs(6);
					prbs(8) <= prbs(0) XOR prbs(4);
					prbs(9) <= prbs(1) XOR prbs(5);
					prbs(10) <= prbs(2) XOR prbs(6);
					prbs(11) <= prbs(0) XOR prbs(3) XOR prbs(6);
					prbs(12) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(6);
					prbs(13) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(5) XOR prbs(6);
					prbs(14) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(3);
					prbs(15) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(4);
					prbs(16) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(5);
					prbs(17) <= prbs(3) XOR prbs(4) XOR prbs(5) XOR prbs(6);
					prbs(18) <= prbs(0) XOR prbs(4) XOR prbs(5);
					prbs(19) <= prbs(1) XOR prbs(5) XOR prbs(6);
					prbs(20) <= prbs(0) XOR prbs(2);
					prbs(21) <= prbs(1) XOR prbs(3);
					prbs(22) <= prbs(2) XOR prbs(4);
					prbs(23) <= prbs(3) XOR prbs(5);
					prbs(24) <= prbs(4) XOR prbs(6);
					prbs(25) <= prbs(0) XOR prbs(5) XOR prbs(6);
					prbs(26) <= prbs(0) XOR prbs(1);
					prbs(27) <= prbs(1) XOR prbs(2);
					prbs(28) <= prbs(2) XOR prbs(3);
					prbs(29) <= prbs(3) XOR prbs(4);
					prbs(30) <= prbs(4) XOR prbs(5);
					prbs(31) <= prbs(5) XOR prbs(6);	
		
								
				WHEN "001" =>	-- PRBS 2^23-1 [23,18] (parallel 32bit serializer) 
					-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
					-- (compatible with E tile Hard Prbs (with polarity inversion off))			
					prbs(0) <= prbs(4) XOR prbs(14) ;
					prbs(1) <= prbs(5) XOR prbs(15) ;
					prbs(2) <= prbs(6) XOR prbs(16) ;
					prbs(3) <= prbs(7) XOR prbs(17) ;
					prbs(4) <= prbs(8) XOR prbs(18) ;
					prbs(5) <= prbs(9) XOR prbs(19) ;
					prbs(6) <= prbs(10) XOR prbs(20) ;
					prbs(7) <= prbs(11) XOR prbs(21) ;
					prbs(8) <= prbs(12) XOR prbs(22) ;
					prbs(9) <= prbs(0) XOR prbs(13) XOR prbs(18) ;
					prbs(10) <= prbs(1) XOR prbs(14) XOR prbs(19) ;
					prbs(11) <= prbs(2) XOR prbs(15) XOR prbs(20) ;
					prbs(12) <= prbs(3) XOR prbs(16) XOR prbs(21) ;
					prbs(13) <= prbs(4) XOR prbs(17) XOR prbs(22) ;
					prbs(14) <= prbs(0) XOR prbs(5) ;
					prbs(15) <= prbs(1) XOR prbs(6) ;
					prbs(16) <= prbs(2) XOR prbs(7) ;
					prbs(17) <= prbs(3) XOR prbs(8) ;
					prbs(18) <= prbs(4) XOR prbs(9) ;
					prbs(19) <= prbs(5) XOR prbs(10) ;
					prbs(20) <= prbs(6) XOR prbs(11) ;
					prbs(21) <= prbs(7) XOR prbs(12) ;
					prbs(22) <= prbs(8) XOR prbs(13) ;
					prbs(23) <= prbs(9) XOR prbs(14) ;
					prbs(24) <= prbs(10) XOR prbs(15) ;
					prbs(25) <= prbs(11) XOR prbs(16) ;
					prbs(26) <= prbs(12) XOR prbs(17) ;
					prbs(27) <= prbs(13) XOR prbs(18) ;
					prbs(28) <= prbs(14) XOR prbs(19) ;
					prbs(29) <= prbs(15) XOR prbs(20) ;
					prbs(30) <= prbs(16) XOR prbs(21) ;
					prbs(31) <= prbs(17) XOR prbs(22) ;

	
					
				WHEN "010"	=>  
					-- -- PRBS 2^31-1 [31,28] (parallel 32bit serializer)
					-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
					-- (compatible with E tile Hard Prbs (with polarity inversion off))
					prbs(0) <= prbs(24) XOR prbs(30) ;
					prbs(1) <= prbs(0) XOR prbs(25) XOR prbs(28) ;
					prbs(2) <= prbs(1) XOR prbs(26) XOR prbs(29) ;
					prbs(3) <= prbs(2) XOR prbs(27) XOR prbs(30) ;
					prbs(4) <= prbs(0) XOR prbs(3) ;
					prbs(5) <= prbs(1) XOR prbs(4) ;
					prbs(6) <= prbs(2) XOR prbs(5) ;
					prbs(7) <= prbs(3) XOR prbs(6) ;
					prbs(8) <= prbs(4) XOR prbs(7) ;
					prbs(9) <= prbs(5) XOR prbs(8) ;
					prbs(10) <= prbs(6) XOR prbs(9) ;
					prbs(11) <= prbs(7) XOR prbs(10) ;
					prbs(12) <= prbs(8) XOR prbs(11) ;
					prbs(13) <= prbs(9) XOR prbs(12) ;
					prbs(14) <= prbs(10) XOR prbs(13) ;
					prbs(15) <= prbs(11) XOR prbs(14) ;
					prbs(16) <= prbs(12) XOR prbs(15) ;
					prbs(17) <= prbs(13) XOR prbs(16) ;
					prbs(18) <= prbs(14) XOR prbs(17) ;
					prbs(19) <= prbs(15) XOR prbs(18) ;
					prbs(20) <= prbs(16) XOR prbs(19) ;
					prbs(21) <= prbs(17) XOR prbs(20) ;
					prbs(22) <= prbs(18) XOR prbs(21) ;
					prbs(23) <= prbs(19) XOR prbs(22) ;
					prbs(24) <= prbs(20) XOR prbs(23) ;
					prbs(25) <= prbs(21) XOR prbs(24) ;
					prbs(26) <= prbs(22) XOR prbs(25) ;
					prbs(27) <= prbs(23) XOR prbs(26) ;
					prbs(28) <= prbs(24) XOR prbs(27) ;
					prbs(29) <= prbs(25) XOR prbs(28) ;
					prbs(30) <= prbs(26) XOR prbs(29) ;
					prbs(31) <= prbs(27) XOR prbs(30) ;
					
					

					
				WHEN "011"  => -- PRBS 2^15-1 (PRBS15 [15 14] (parallel 32-bit serializer) 
					-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
					-- (compatible with E tile Hard Prbs (with polarity inversion off))
					prbs(0) <= prbs(10) XOR prbs(11) XOR prbs(12) XOR prbs(13) ;
					prbs(1) <= prbs(11) XOR prbs(12) XOR prbs(13) XOR prbs(14) ;
					prbs(2) <= prbs(0) XOR prbs(12) XOR prbs(13) ;
					prbs(3) <= prbs(1) XOR prbs(13) XOR prbs(14) ;
					prbs(4) <= prbs(0) XOR prbs(2) ;
					prbs(5) <= prbs(1) XOR prbs(3) ;
					prbs(6) <= prbs(2) XOR prbs(4) ;
					prbs(7) <= prbs(3) XOR prbs(5) ;
					prbs(8) <= prbs(4) XOR prbs(6) ;
					prbs(9) <= prbs(5) XOR prbs(7) ;
					prbs(10) <= prbs(6) XOR prbs(8) ;
					prbs(11) <= prbs(7) XOR prbs(9) ;
					prbs(12) <= prbs(8) XOR prbs(10) ;
					prbs(13) <= prbs(9) XOR prbs(11) ;
					prbs(14) <= prbs(10) XOR prbs(12) ;
					prbs(15) <= prbs(11) XOR prbs(13) ;
					prbs(16) <= prbs(12) XOR prbs(14) ;
					prbs(17) <= prbs(0) XOR prbs(13) XOR prbs(14) ;
					prbs(18) <= prbs(0) XOR prbs(1) ;
					prbs(19) <= prbs(1) XOR prbs(2) ;
					prbs(20) <= prbs(2) XOR prbs(3) ;
					prbs(21) <= prbs(3) XOR prbs(4) ;
					prbs(22) <= prbs(4) XOR prbs(5) ;
					prbs(23) <= prbs(5) XOR prbs(6) ;
					prbs(24) <= prbs(6) XOR prbs(7) ;
					prbs(25) <= prbs(7) XOR prbs(8) ;
					prbs(26) <= prbs(8) XOR prbs(9) ;
					prbs(27) <= prbs(9) XOR prbs(10) ;
					prbs(28) <= prbs(10) XOR prbs(11) ;
					prbs(29) <= prbs(11) XOR prbs(12) ;
					prbs(30) <= prbs(12) XOR prbs(13) ;
					prbs(31) <= prbs(13) XOR prbs(14) ;

			
				WHEN "100"  => -- High Frequency
					prbs <= X"AAAAAAAA";
				WHEN "101"  => -- Low Frequency
					prbs <= X"FF00FF00"; -- Frequency divided by 8 (minimum datarate is 1 Gbps).
					
				WHEN "110" => -- PRBS 2^9-1 (PRBS9 [9 5] (parallel 32-bit serializer)
					-- (compatible with L/H tile Hard Prbs (with polarity inversion on)) 
					-- (compatible with E tile Hard Prbs (with polarity inversion off))												
					prbs(0) <= prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(7) ;										
					prbs(1) <= prbs(4) XOR prbs(5) XOR prbs(7) XOR prbs(8) ;										
					prbs(2) <= prbs(0) XOR prbs(6) XOR prbs(8) ;										
					prbs(3) <= prbs(0) XOR prbs(1) XOR prbs(5) XOR prbs(7) ;										
					prbs(4) <= prbs(1) XOR prbs(2) XOR prbs(6) XOR prbs(8) ;										
					prbs(5) <= prbs(0) XOR prbs(2) XOR prbs(3) XOR prbs(5) XOR prbs(7) ;										
					prbs(6) <= prbs(1) XOR prbs(3) XOR prbs(4) XOR prbs(6) XOR prbs(8) ;										
					prbs(7) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(7) ;										
					prbs(8) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(8) ;										
					prbs(9) <= prbs(0) XOR prbs(2) XOR prbs(4) XOR prbs(5) XOR prbs(6) ;										
					prbs(10) <= prbs(1) XOR prbs(3) XOR prbs(5) XOR prbs(6) XOR prbs(7) ;										
					prbs(11) <= prbs(2) XOR prbs(4) XOR prbs(6) XOR prbs(7) XOR prbs(8) ;										
					prbs(12) <= prbs(0) XOR prbs(3) XOR prbs(7) XOR prbs(8) ;										
					prbs(13) <= prbs(0) XOR prbs(1) XOR prbs(4) XOR prbs(5) XOR prbs(8) ;										
					prbs(14) <= prbs(0) XOR prbs(1) XOR prbs(2) XOR prbs(6) ;										
					prbs(15) <= prbs(1) XOR prbs(2) XOR prbs(3) XOR prbs(7) ;										
					prbs(16) <= prbs(2) XOR prbs(3) XOR prbs(4) XOR prbs(8) ;										
					prbs(17) <= prbs(0) XOR prbs(3) XOR prbs(4) ;										
					prbs(18) <= prbs(1) XOR prbs(4) XOR prbs(5) ;										
					prbs(19) <= prbs(2) XOR prbs(5) XOR prbs(6) ;										
					prbs(20) <= prbs(3) XOR prbs(6) XOR prbs(7) ;										
					prbs(21) <= prbs(4) XOR prbs(7) XOR prbs(8) ;										
					prbs(22) <= prbs(0) XOR prbs(8) ;										
					prbs(23) <= prbs(0) XOR prbs(1) XOR prbs(5) ;										
					prbs(24) <= prbs(1) XOR prbs(2) XOR prbs(6) ;										
					prbs(25) <= prbs(2) XOR prbs(3) XOR prbs(7) ;										
					prbs(26) <= prbs(3) XOR prbs(4) XOR prbs(8) ;										
					prbs(27) <= prbs(0) XOR prbs(4) ;										
					prbs(28) <= prbs(1) XOR prbs(5) ;										
					prbs(29) <= prbs(2) XOR prbs(6) ;										
					prbs(30) <= prbs(3) XOR prbs(7) ;										
					prbs(31) <= prbs(4) XOR prbs(8) ;		
--				WHEN "111"  => -- Sonet Header every 64 clock cycles, remaining high frequency
--					if (count = "111111") then
--						prbs <= X"F6F62828";
--						count <= (OTHERS => '0');
--					else
--						prbs <= X"AAAAAAAA";	
--						count <= count + 1;
--					end if;
					
				WHEN "111"  => -- FEEDBEEF every 64 clock cycles, rest is zero (to test the scrambling)
					if (count = "111111") then
						prbs <= X"FEEDBEEF";
						--prbs <= X"F77DB77F";	-- because of swap					
						count <= (OTHERS => '0');
					else
						prbs <= (OTHERS => '0');
						count <= count + 1;
					end if;

					
				WHEN OTHERS => NULL;
				END CASE;
		  end if; --Enable
		  end if;
		end if;
	end process;

	process(coreclk)
	begin
		if rising_edge(coreclk) then
		
			if (Reset_dupA2 = '1') then
				tx_data <= X"07070707";
				--tx_data <= X"E0E0E0E0";  -- because of swap later 
				Valid_min1 <= '0';	

					detect_inserterror <= '0';	
				delayed_error <= '0';
				inserterror_q <= '0';
				
			else

				

				inserterror_q <= inserterror_synchro;
				
					if (inserterror_q /= inserterror_synchro) and (inserterror_synchro = '1') then
						detect_inserterror <= '1';
					else
						detect_inserterror <= '0';
					end if;
					
			if Enable = '1' then 
					--CountPattern <= CountPattern + 1;

					if delayed_error = '1' then
						delayed_error <= '0';
					end if;	
				if detect_inserterror = '1' or delayed_error = '1' then 
						report "==========================================================================================================> Inserted one bit error in Tx data ..." severity note;
					tx_data <= (not prbs(31)) & prbs(30 downto 0);			-- insert One biterror
					else
					tx_data <= prbs(31 downto 0);
						--tx_data <= tx_data + 1;
					end if;
				Valid_min1 <= '1';
			else
					if detect_inserterror = '1' then
						delayed_error <= '1';
					end if;					
					tx_data <= X"07070707";
					--tx_data <= X"E0E0E0E0"; -- because of swap later 
					Valid_min1 <= '0';
			end if;

		
			 end if;	
		end if;
	end process;
	
	process(coreclk)
	begin
		if rising_edge(coreclk) then		
			SwapMSB_With_LSB:
			FOR i IN 0 to 31 LOOP
			   if (INVERT_POLARITY_PRBS) then 
					tx_data_sig(i) <= not(tx_data(31-i));
				else
					tx_data_sig(i) <= (tx_data(31-i));
				end if;
			END LOOP SwapMSB_With_LSB;		
			
		

		 Valid <= Valid_min1;	
		
		end if;
	end process;
	
Prbsout <= tx_data_sig;

		
			
end;


