library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;

entity multi_prbsverify_32bit is
GENERIC
	(
		USE_ADDER_HW					:  boolean := true;
		INVERT_POLARITY_PRBS			:  boolean := true  -- For L/H tile set to true, For E-tile set to false (allows compatibility with Hard PRBS generators/checkers)
	);
PORT(
    Clock               : in std_logic;
	Enable			: in std_logic;
    Reset               : in std_logic;
    ResetErrorCount     : in std_logic;
    PrbsSelect          : in std_logic_vector(2 downto 0);
    DataIn              : in std_logic_vector(31 downto 0);
    PrbsLocked          : out std_logic;
    Errorcount_Q        : out std_logic_vector(63 downto 0)
    );
END multi_prbsverify_32bit;

architecture rtl of multi_prbsverify_32bit is


	component adder_hw is
		port (
			accum_sload : in  std_logic                     := 'X';             -- accum_sload
			aclr0       : in  std_logic                     := 'X';             -- aclr0
			clock0      : in  std_logic                     := 'X';             -- clock0
			dataa_0     : in  std_logic_vector(26 downto 0) := (others => 'X'); -- dataa_0
			datab_0     : in  std_logic_vector(26 downto 0) := (others => 'X'); -- datab_0
			result      : out std_logic_vector(63 downto 0)                     -- result
		);
	end component adder_hw;
	
	

type   Array_8x6bit	 is array (0 to 8) of std_logic_vector(5 downto 0);
type   Array_2x6bit	 is array (0 to 1) of std_logic_vector(5 downto 0);
signal next_prbs                : std_logic_vector(31 downto 0);

	
	
signal next_prbs_pipe			: std_logic_vector(31 downto 0);
signal next_prbs_7              : std_logic_vector(31 downto 0);
signal next_prbs_15             : std_logic_vector(31 downto 0);
signal next_prbs_23             : std_logic_vector(31 downto 0);
signal next_prbs_31             : std_logic_vector(31 downto 0);
signal next_prbs_9              : std_logic_vector(31 downto 0);

signal prbs2                    : std_logic_vector(31 downto 0);
signal prbs2_7, prbs2_15, prbs2_23, prbs2_31 ,prbs2_9					: std_logic_vector(31 downto 0);
signal rcv_data                 : std_logic_vector(31 downto 0);

signal count                    : unsigned(7 downto 0);
signal count_no_match           : unsigned(7 downto 0);

signal lock                     : std_logic;
signal no_match                 : std_logic;
signal no_match_W	            : std_logic_vector(7 downto 0);
signal no_match_Z               : std_logic_vector(3 downto 0);

signal no_match_zero                : std_logic;
signal detect_selectchannel     : std_logic;

signal LSBRcvData               : std_logic_vector(31 downto 0);
signal LSBRcvData_pipe 			: std_logic_vector(31 downto 0);
signal LSBRcvData_pipe_min1 	: std_logic_vector(31 downto 0);

signal ErrorCount_adder_hw		: std_logic_vector(63 downto 0) := (OTHERS=> '0');
signal ErrorCount_sim			: std_logic_vector(63 downto 0) := (OTHERS=> '0');
signal ErrorCount_pipe			: std_logic_vector(63 downto 0);
signal Difference_tot         : std_logic_vector(5 downto 0);
signal Difference					: Array_8x6bit;
signal Difference_min         : Array_2x6bit;
signal Difference_pipe			: std_logic_vector(5 downto 0);
signal Difference_adder			: std_logic_vector(5 downto 0);
signal Resetadder					: std_logic;

signal Difference_adder_27b : std_logic_vector(26 downto 0); 
signal const_one : std_logic_vector(26 downto 0); 
attribute keep : boolean; 
attribute keep of const_one : signal is true; 
signal PrbsSelect_s1, PrbsSelect_s2, PrbsSelect_s3 : std_logic_vector(2 downto 0); 
signal Reset_dupA1, Reset_dupA2,  Reset_dupB1, Reset_dupB2	 			:  std_logic :='0';
attribute preserve_syn_only : boolean;
attribute preserve_syn_only of Reset_dupA1 : signal is true;
attribute preserve_syn_only of Reset_dupB1 : signal is true;
signal CheckZeroes              : std_logic_vector(63 downto 0);

begin


	process(Clock)
	begin
		if rising_edge(Clock) then	
				Reset_dupA1 <= Reset;
				Reset_dupA2 <= Reset_dupA1;
				Reset_dupB1 <= Reset;
				Reset_dupB2 <= Reset_dupB1;
			if (Reset_dupA2 = '1') then
				--prbs2 <= (OTHERS => '0');
				prbs2_7 <= (OTHERS => '0');
				prbs2_15 <= (OTHERS => '0');
				prbs2_23 <= (OTHERS => '0');
				prbs2_31 <= (OTHERS => '0');
				prbs2_9 <= (OTHERS => '0');
--				rcv_data <= (OTHERS => '0');
				LSBRcvData 	<= (OTHERS => '0');
				PrbsSelect_s1 <= (OTHERS => '0'); 
				PrbsSelect_s2 <= (OTHERS => '0'); 
				PrbsSelect_s3 <= (OTHERS => '0'); 
			else
				PrbsSelect_s1 <= PrbsSelect; 
				PrbsSelect_s2 <= PrbsSelect_s1; 
				PrbsSelect_s3 <= PrbsSelect_s2; 

			if Enable = '1' then
                SwapMSB_With_LSB:
                FOR i IN 0 to 31 LOOP
								if (INVERT_POLARITY_PRBS) then
									rcv_data(i) <= not (DataIn(31-i));                             
								else
									rcv_data(i) <= (DataIn(31-i));  
								end if;
						 END LOOP SwapMSB_With_LSB;

					LSBRcvData_pipe_min1 	<= rcv_data;		-- reclock the data
					LSBRcvData		 			<= LSBRcvData_pipe_min1;	-- Retimer since next_prbs is also being retimed.		

                if lock = '1' then
                    --prbs2 <= next_prbs;
							prbs2_7 <= next_prbs_7;
							prbs2_15 <= next_prbs_15;
							prbs2_23 <= next_prbs_23;
							prbs2_31 <= next_prbs_31;
							prbs2_9 <= next_prbs_9;
                else
                   -- prbs2 <= LSBRcvData;
							prbs2_7 <= LSBRcvData_pipe_min1;
							prbs2_15 <= LSBRcvData_pipe_min1;
							prbs2_23 <= LSBRcvData_pipe_min1;
							prbs2_31 <= LSBRcvData_pipe_min1;
							prbs2_9 <= LSBRcvData_pipe_min1;
                end if;
        end if;
		end if;
		end if;
    end process;


    process(Clock)
    begin
		if rising_edge(Clock) then
			if (Reset_dupA2 = '1') then
                lock <= '0';
                no_match <= '1';
				FOR J in 0 to 7	Loop		
					no_match_W(J) <= '1';					
				end loop;
				FOR J in 0 to 3	Loop		
					no_match_Z(J) <= '1';					
				end loop;				

                no_match_zero <= '1';
                count <= (OTHERS => '0');
                count_no_match <=(Others => '0');


        else
		
				if Enable = '1' then
                if no_match = '1' then
                    count <= (Others => '0');
                    count_no_match <= count_no_match + 1;
                else
                    count <= count + 1;
                    count_no_match <=(Others => '0');
                end if;
				if count(7) = '1' and count_no_match(0) = '0' then -- Receive 64 consecutive words without any errors before declaring lock
                    lock <= '1';
                    assert(lock = '1')
                    report "==========================================================================================================> PrbsLock achieved ..."      severity note;
                elsif count(0) = '0' and count_no_match(7) = '1' then -- Receive 64 consecutive words not correct before declaring loss
                    lock <= '0';
					else
						lock <= lock;
                end if;



					next_prbs <= next_prbs_pipe; -- Retime next_prbs for performance
					FOR J in 0 to 7	Loop			
			           if ( next_prbs((3 + (4*J)) downto (4*J)) /= LSBRcvData((3 + (4*J)) downto (4*J)) )  then
                        no_match_W(J) <= '1';
                    else
                        no_match_W(J) <= '0';
                    end if;
					end loop;




                    -- check for zeroes

 					FOR J in 0 to 3	Loop			
			           if ( LSBRcvData((7 + (8*J)) downto (8*J)) = X"0000")  then
                        no_match_Z(J) <= '1';
                    else
                        no_match_Z(J) <= '0';
                    end if;
					end loop;





					if (no_match_Z(0) = '1') and ( no_match_Z(1) = '1') and ( no_match_Z(2) = '1') and ( no_match_Z(3) = '1') then
                        no_match_zero <= '1';
                    else
                        no_match_zero <= '0';
                    end if;


					if (no_match_W(0) = '1') or ( no_match_W(1) = '1') or ( no_match_W(2) = '1') or ( no_match_W(3) = '1') or (no_match_W(4) = '1') or ( no_match_W(5) = '1') or ( no_match_W(6) = '1') or ( no_match_W(7) = '1') or (no_match_zero = '1') then
                        no_match <= '1';        -- One pipeline stage for performance
                        if lock = '1' then
                            report "==========================================================================================================> Found a data mis-match in last received word " severity note;
                        end if;
                    else
                        no_match <= '0';
                    end if;

        end if;
   end if;
		end if;
    end process;

-- PRBS 2^7-1 (parallel 32-bit serializer) (T[7,6]) 
-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
-- (compatible with E tile Hard Prbs (with polarity inversion off))	

next_prbs_7(0) <= prbs2_7(2) XOR prbs2_7(3) XOR prbs2_7(4) XOR prbs2_7(6);
next_prbs_7(1) <= prbs2_7(0) XOR prbs2_7(3) XOR prbs2_7(4) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(2) <= prbs2_7(0) XOR prbs2_7(1) XOR prbs2_7(4) XOR prbs2_7(5);
next_prbs_7(3) <= prbs2_7(1) XOR prbs2_7(2) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(4) <= prbs2_7(0) XOR prbs2_7(2) XOR prbs2_7(3);
next_prbs_7(5) <= prbs2_7(1) XOR prbs2_7(3) XOR prbs2_7(4);
next_prbs_7(6) <= prbs2_7(2) XOR prbs2_7(4) XOR prbs2_7(5);
next_prbs_7(7) <= prbs2_7(3) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(8) <= prbs2_7(0) XOR prbs2_7(4);
next_prbs_7(9) <= prbs2_7(1) XOR prbs2_7(5);
next_prbs_7(10) <= prbs2_7(2) XOR prbs2_7(6);
next_prbs_7(11) <= prbs2_7(0) XOR prbs2_7(3) XOR prbs2_7(6);
next_prbs_7(12) <= prbs2_7(0) XOR prbs2_7(1) XOR prbs2_7(4) XOR prbs2_7(6);
next_prbs_7(13) <= prbs2_7(0) XOR prbs2_7(1) XOR prbs2_7(2) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(14) <= prbs2_7(0) XOR prbs2_7(1) XOR prbs2_7(2) XOR prbs2_7(3);
next_prbs_7(15) <= prbs2_7(1) XOR prbs2_7(2) XOR prbs2_7(3) XOR prbs2_7(4);
next_prbs_7(16) <= prbs2_7(2) XOR prbs2_7(3) XOR prbs2_7(4) XOR prbs2_7(5);
next_prbs_7(17) <= prbs2_7(3) XOR prbs2_7(4) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(18) <= prbs2_7(0) XOR prbs2_7(4) XOR prbs2_7(5);
next_prbs_7(19) <= prbs2_7(1) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(20) <= prbs2_7(0) XOR prbs2_7(2);
next_prbs_7(21) <= prbs2_7(1) XOR prbs2_7(3);
next_prbs_7(22) <= prbs2_7(2) XOR prbs2_7(4);
next_prbs_7(23) <= prbs2_7(3) XOR prbs2_7(5);
next_prbs_7(24) <= prbs2_7(4) XOR prbs2_7(6);
next_prbs_7(25) <= prbs2_7(0) XOR prbs2_7(5) XOR prbs2_7(6);
next_prbs_7(26) <= prbs2_7(0) XOR prbs2_7(1);
next_prbs_7(27) <= prbs2_7(1) XOR prbs2_7(2);
next_prbs_7(28) <= prbs2_7(2) XOR prbs2_7(3);
next_prbs_7(29) <= prbs2_7(3) XOR prbs2_7(4);
next_prbs_7(30) <= prbs2_7(4) XOR prbs2_7(5);
next_prbs_7(31) <= prbs2_7(5) XOR prbs2_7(6);



-- PRBS 2^23-1 [23,18] (parallel 32-bit serializer)
-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
-- (compatible with E tile Hard Prbs (with polarity inversion off))	

next_prbs_23(0) <= prbs2_23(4) XOR prbs2_23(14) ;
next_prbs_23(1) <= prbs2_23(5) XOR prbs2_23(15) ;
next_prbs_23(2) <= prbs2_23(6) XOR prbs2_23(16) ;
next_prbs_23(3) <= prbs2_23(7) XOR prbs2_23(17) ;
next_prbs_23(4) <= prbs2_23(8) XOR prbs2_23(18) ;
next_prbs_23(5) <= prbs2_23(9) XOR prbs2_23(19) ;
next_prbs_23(6) <= prbs2_23(10) XOR prbs2_23(20) ;
next_prbs_23(7) <= prbs2_23(11) XOR prbs2_23(21) ;
next_prbs_23(8) <= prbs2_23(12) XOR prbs2_23(22) ;
next_prbs_23(9) <= prbs2_23(0) XOR prbs2_23(13) XOR prbs2_23(18) ;
next_prbs_23(10) <= prbs2_23(1) XOR prbs2_23(14) XOR prbs2_23(19) ;
next_prbs_23(11) <= prbs2_23(2) XOR prbs2_23(15) XOR prbs2_23(20) ;
next_prbs_23(12) <= prbs2_23(3) XOR prbs2_23(16) XOR prbs2_23(21) ;
next_prbs_23(13) <= prbs2_23(4) XOR prbs2_23(17) XOR prbs2_23(22) ;
next_prbs_23(14) <= prbs2_23(0) XOR prbs2_23(5) ;
next_prbs_23(15) <= prbs2_23(1) XOR prbs2_23(6) ;
next_prbs_23(16) <= prbs2_23(2) XOR prbs2_23(7) ;
next_prbs_23(17) <= prbs2_23(3) XOR prbs2_23(8) ;
next_prbs_23(18) <= prbs2_23(4) XOR prbs2_23(9) ;
next_prbs_23(19) <= prbs2_23(5) XOR prbs2_23(10) ;
next_prbs_23(20) <= prbs2_23(6) XOR prbs2_23(11) ;
next_prbs_23(21) <= prbs2_23(7) XOR prbs2_23(12) ;
next_prbs_23(22) <= prbs2_23(8) XOR prbs2_23(13) ;
next_prbs_23(23) <= prbs2_23(9) XOR prbs2_23(14) ;
next_prbs_23(24) <= prbs2_23(10) XOR prbs2_23(15) ;
next_prbs_23(25) <= prbs2_23(11) XOR prbs2_23(16) ;
next_prbs_23(26) <= prbs2_23(12) XOR prbs2_23(17) ;
next_prbs_23(27) <= prbs2_23(13) XOR prbs2_23(18) ;
next_prbs_23(28) <= prbs2_23(14) XOR prbs2_23(19) ;
next_prbs_23(29) <= prbs2_23(15) XOR prbs2_23(20) ;
next_prbs_23(30) <= prbs2_23(16) XOR prbs2_23(21) ;
next_prbs_23(31) <= prbs2_23(17) XOR prbs2_23(22) ;





-- PRBS 2^31-1 [31,28] (parallel 32-bit serializer)
-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
-- (compatible with E tile Hard Prbs (with polarity inversion off))	

next_prbs_31(0) <= prbs2_31(24) XOR prbs2_31(30) ;
next_prbs_31(1) <= prbs2_31(0) XOR prbs2_31(25) XOR prbs2_31(28) ;
next_prbs_31(2) <= prbs2_31(1) XOR prbs2_31(26) XOR prbs2_31(29) ;
next_prbs_31(3) <= prbs2_31(2) XOR prbs2_31(27) XOR prbs2_31(30) ;
next_prbs_31(4) <= prbs2_31(0) XOR prbs2_31(3) ;
next_prbs_31(5) <= prbs2_31(1) XOR prbs2_31(4) ;
next_prbs_31(6) <= prbs2_31(2) XOR prbs2_31(5) ;
next_prbs_31(7) <= prbs2_31(3) XOR prbs2_31(6) ;
next_prbs_31(8) <= prbs2_31(4) XOR prbs2_31(7) ;
next_prbs_31(9) <= prbs2_31(5) XOR prbs2_31(8) ;
next_prbs_31(10) <= prbs2_31(6) XOR prbs2_31(9) ;
next_prbs_31(11) <= prbs2_31(7) XOR prbs2_31(10) ;
next_prbs_31(12) <= prbs2_31(8) XOR prbs2_31(11) ;
next_prbs_31(13) <= prbs2_31(9) XOR prbs2_31(12) ;
next_prbs_31(14) <= prbs2_31(10) XOR prbs2_31(13) ;
next_prbs_31(15) <= prbs2_31(11) XOR prbs2_31(14) ;
next_prbs_31(16) <= prbs2_31(12) XOR prbs2_31(15) ;
next_prbs_31(17) <= prbs2_31(13) XOR prbs2_31(16) ;
next_prbs_31(18) <= prbs2_31(14) XOR prbs2_31(17) ;
next_prbs_31(19) <= prbs2_31(15) XOR prbs2_31(18) ;
next_prbs_31(20) <= prbs2_31(16) XOR prbs2_31(19) ;
next_prbs_31(21) <= prbs2_31(17) XOR prbs2_31(20) ;
next_prbs_31(22) <= prbs2_31(18) XOR prbs2_31(21) ;
next_prbs_31(23) <= prbs2_31(19) XOR prbs2_31(22) ;
next_prbs_31(24) <= prbs2_31(20) XOR prbs2_31(23) ;
next_prbs_31(25) <= prbs2_31(21) XOR prbs2_31(24) ;
next_prbs_31(26) <= prbs2_31(22) XOR prbs2_31(25) ;
next_prbs_31(27) <= prbs2_31(23) XOR prbs2_31(26) ;
next_prbs_31(28) <= prbs2_31(24) XOR prbs2_31(27) ;
next_prbs_31(29) <= prbs2_31(25) XOR prbs2_31(28) ;
next_prbs_31(30) <= prbs2_31(26) XOR prbs2_31(29) ;
next_prbs_31(31) <= prbs2_31(27) XOR prbs2_31(30) ;





-- PRBS 2^15-1 (PRBS15 [15 14] (parallel 32-bit serializer)
-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
-- (compatible with E tile Hard Prbs (with polarity inversion off))	


next_prbs_15(0) <= prbs2_15(10) XOR prbs2_15(11) XOR prbs2_15(12) XOR prbs2_15(13) ;
next_prbs_15(1) <= prbs2_15(11) XOR prbs2_15(12) XOR prbs2_15(13) XOR prbs2_15(14) ;
next_prbs_15(2) <= prbs2_15(0) XOR prbs2_15(12) XOR prbs2_15(13) ;
next_prbs_15(3) <= prbs2_15(1) XOR prbs2_15(13) XOR prbs2_15(14) ;
next_prbs_15(4) <= prbs2_15(0) XOR prbs2_15(2) ;
next_prbs_15(5) <= prbs2_15(1) XOR prbs2_15(3) ;
next_prbs_15(6) <= prbs2_15(2) XOR prbs2_15(4) ;
next_prbs_15(7) <= prbs2_15(3) XOR prbs2_15(5) ;
next_prbs_15(8) <= prbs2_15(4) XOR prbs2_15(6) ;
next_prbs_15(9) <= prbs2_15(5) XOR prbs2_15(7) ;
next_prbs_15(10) <= prbs2_15(6) XOR prbs2_15(8) ;
next_prbs_15(11) <= prbs2_15(7) XOR prbs2_15(9) ;
next_prbs_15(12) <= prbs2_15(8) XOR prbs2_15(10) ;
next_prbs_15(13) <= prbs2_15(9) XOR prbs2_15(11) ;
next_prbs_15(14) <= prbs2_15(10) XOR prbs2_15(12) ;
next_prbs_15(15) <= prbs2_15(11) XOR prbs2_15(13) ;
next_prbs_15(16) <= prbs2_15(12) XOR prbs2_15(14) ;
next_prbs_15(17) <= prbs2_15(0) XOR prbs2_15(13) XOR prbs2_15(14) ;
next_prbs_15(18) <= prbs2_15(0) XOR prbs2_15(1) ;
next_prbs_15(19) <= prbs2_15(1) XOR prbs2_15(2) ;
next_prbs_15(20) <= prbs2_15(2) XOR prbs2_15(3) ;
next_prbs_15(21) <= prbs2_15(3) XOR prbs2_15(4) ;
next_prbs_15(22) <= prbs2_15(4) XOR prbs2_15(5) ;
next_prbs_15(23) <= prbs2_15(5) XOR prbs2_15(6) ;
next_prbs_15(24) <= prbs2_15(6) XOR prbs2_15(7) ;
next_prbs_15(25) <= prbs2_15(7) XOR prbs2_15(8) ;
next_prbs_15(26) <= prbs2_15(8) XOR prbs2_15(9) ;
next_prbs_15(27) <= prbs2_15(9) XOR prbs2_15(10) ;
next_prbs_15(28) <= prbs2_15(10) XOR prbs2_15(11) ;
next_prbs_15(29) <= prbs2_15(11) XOR prbs2_15(12) ;
next_prbs_15(30) <= prbs2_15(12) XOR prbs2_15(13) ;
next_prbs_15(31) <= prbs2_15(13) XOR prbs2_15(14) ;

-- PRBS 2^9-1 (PRBS9 [9 5] (parallel 32-bit serializer)
-- (compatible with L/H tile Hard Prbs (with polarity inversion on))
-- (compatible with E tile Hard Prbs (with polarity inversion off))	
									
next_prbs_9(0) <= prbs2_9(3) XOR prbs2_9(4) XOR prbs2_9(6) XOR prbs2_9(7) ;										
next_prbs_9(1) <= prbs2_9(4) XOR prbs2_9(5) XOR prbs2_9(7) XOR prbs2_9(8) ;										
next_prbs_9(2) <= prbs2_9(0) XOR prbs2_9(6) XOR prbs2_9(8) ;										
next_prbs_9(3) <= prbs2_9(0) XOR prbs2_9(1) XOR prbs2_9(5) XOR prbs2_9(7) ;										
next_prbs_9(4) <= prbs2_9(1) XOR prbs2_9(2) XOR prbs2_9(6) XOR prbs2_9(8) ;										
next_prbs_9(5) <= prbs2_9(0) XOR prbs2_9(2) XOR prbs2_9(3) XOR prbs2_9(5) XOR prbs2_9(7) ;										
next_prbs_9(6) <= prbs2_9(1) XOR prbs2_9(3) XOR prbs2_9(4) XOR prbs2_9(6) XOR prbs2_9(8) ;										
next_prbs_9(7) <= prbs2_9(0) XOR prbs2_9(2) XOR prbs2_9(4) XOR prbs2_9(7) ;										
next_prbs_9(8) <= prbs2_9(1) XOR prbs2_9(3) XOR prbs2_9(5) XOR prbs2_9(8) ;										
next_prbs_9(9) <= prbs2_9(0) XOR prbs2_9(2) XOR prbs2_9(4) XOR prbs2_9(5) XOR prbs2_9(6) ;										
next_prbs_9(10) <= prbs2_9(1) XOR prbs2_9(3) XOR prbs2_9(5) XOR prbs2_9(6) XOR prbs2_9(7) ;										
next_prbs_9(11) <= prbs2_9(2) XOR prbs2_9(4) XOR prbs2_9(6) XOR prbs2_9(7) XOR prbs2_9(8) ;										
next_prbs_9(12) <= prbs2_9(0) XOR prbs2_9(3) XOR prbs2_9(7) XOR prbs2_9(8) ;										
next_prbs_9(13) <= prbs2_9(0) XOR prbs2_9(1) XOR prbs2_9(4) XOR prbs2_9(5) XOR prbs2_9(8) ;										
next_prbs_9(14) <= prbs2_9(0) XOR prbs2_9(1) XOR prbs2_9(2) XOR prbs2_9(6) ;										
next_prbs_9(15) <= prbs2_9(1) XOR prbs2_9(2) XOR prbs2_9(3) XOR prbs2_9(7) ;										
next_prbs_9(16) <= prbs2_9(2) XOR prbs2_9(3) XOR prbs2_9(4) XOR prbs2_9(8) ;										
next_prbs_9(17) <= prbs2_9(0) XOR prbs2_9(3) XOR prbs2_9(4) ;										
next_prbs_9(18) <= prbs2_9(1) XOR prbs2_9(4) XOR prbs2_9(5) ;										
next_prbs_9(19) <= prbs2_9(2) XOR prbs2_9(5) XOR prbs2_9(6) ;										
next_prbs_9(20) <= prbs2_9(3) XOR prbs2_9(6) XOR prbs2_9(7) ;										
next_prbs_9(21) <= prbs2_9(4) XOR prbs2_9(7) XOR prbs2_9(8) ;										
next_prbs_9(22) <= prbs2_9(0) XOR prbs2_9(8) ;										
next_prbs_9(23) <= prbs2_9(0) XOR prbs2_9(1) XOR prbs2_9(5) ;										
next_prbs_9(24) <= prbs2_9(1) XOR prbs2_9(2) XOR prbs2_9(6) ;										
next_prbs_9(25) <= prbs2_9(2) XOR prbs2_9(3) XOR prbs2_9(7) ;										
next_prbs_9(26) <= prbs2_9(3) XOR prbs2_9(4) XOR prbs2_9(8) ;										
next_prbs_9(27) <= prbs2_9(0) XOR prbs2_9(4) ;										
next_prbs_9(28) <= prbs2_9(1) XOR prbs2_9(5) ;										
next_prbs_9(29) <= prbs2_9(2) XOR prbs2_9(6) ;										
next_prbs_9(30) <= prbs2_9(3) XOR prbs2_9(7) ;										
next_prbs_9(31) <= prbs2_9(4) XOR prbs2_9(8) ;	



next_prbs_pipe   <=  next_prbs_7  WHEN PrbsSelect_s3 = "000" ELSE
                next_prbs_23 WHEN PrbsSelect_s3 = "001" ELSE
                next_prbs_31 WHEN PrbsSelect_s3 = "010" ELSE
                next_prbs_15 WHEN PrbsSelect_s3 = "011" ELSE
                next_prbs_9 WHEN PrbsSelect_s3 = "110" ELSE
                (OTHERS => '0');




Process(Clock)
variable N : Array_8x6bit;
Begin
	if Clock'event AND Clock = '1' then
		if (ResetErrorcount = '1') or (Reset_dupA2 = '1') then
		
			FOR i IN 0 to 7 LOOP
				Difference(i) <= (OTHERS => '0');
			end loop;
			
			FOR i IN 0 to 1 LOOP
				Difference_min(i) <= (OTHERS => '0');
			end loop;			

			Difference_tot  <= (OTHERS => '0');
				Difference_adder  <= (OTHERS => '0');
    	else

		if Enable = '1' then	
 			FOR i IN 0 to 7 LOOP
            N(I) := (OTHERS => '0');
			END LOOP;
			
			FOR J in 0 to 7 Loop
            for I in 0 to 3 loop
					if next_prbs(J*4 + I) /= LSBRcvData(J*4 + I) then
						N(J) := N(J) +1;
                end if;
            end loop;
            end loop;
			
			FOR i IN 0 to 7 LOOP
				Difference(I) <= N(I);
			END LOOP;

 
			for I in 0 to 1 loop
					Difference_min(I)  <= Difference(0+4*I) + Difference(1+4*I)  + Difference(2+4*I)  + Difference(3+4*I);
            end loop;
			
         Difference_tot   <= Difference_min(0) + Difference_min(1);
			Difference_pipe  <= Difference_tot; -- extra pipeline

			if lock = '1' then
				Difference_adder <= Difference_pipe;
			else
				Difference_adder <= (OTHERS => '0');
			end if;

			--Fast simulation without accumulator
			
            if lock = '1' then
                ErrorCount_sim <= ErrorCount_sim + Difference_adder;
            end if;

				
			end if; -- Validdata

    end if;
 end if;
End Process;

Process(Clock)
Begin
	if Clock'event AND Clock = '1' then
			Resetadder <= ResetErrorcount  or Reset_dupB2 ; -- to remove recovery timing issue
	end if;
end process;

generate_adder_hw:
if (USE_ADDER_HW) generate

adder_hw_inst :  adder_hw
	port map (
	   accum_sload => '0',
		aclr0   => Resetadder,
		clock0  => Clock,
		dataa_0 => Difference_adder_27b,
		datab_0 => const_one,
		result  => ErrorCount_adder_hw
	);
end generate generate_adder_hw;

const_one <= "000000000000000000000000001";	
Difference_adder_27b <= "000000000000000000000" & Difference_adder;

PrbsLocked <= lock;

-- choose either the output from the accumulator or the simulation output.
ErrorCount_Q <= ErrorCount_adder_hw when (USE_ADDER_HW) else ErrorCount_sim;

end;



