


LIBRARY ieee;                                               
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;                       
                          

ENTITY testbench_prbs IS
END testbench_prbs;

ARCHITECTURE PrbsTest_arch OF testbench_prbs IS
-- constants                                                 
-- signals                                                   

CONSTANT PRBSWIDTH 			: integer := 256;


SIGNAL Reset		: STD_LOGIC := '1';
SIGNAL RefClock 	: STD_LOGIC := '0';
SIGNAL Prbsout 	: std_logic_vector(PRBSWIDTH-1 downto 0);
SIGNAL valid		: std_logic;
SIGNAL prbsverify_data_in : std_logic_vector(PRBSWIDTH-1 downto 0);
SIGNAL prbslocked	: std_logic;
SIGNAL Errorcount	: std_logic_vector(63 downto 0);
SIGNAL Inserterror	: std_logic;
SIGNAL PrbsSelect 	: std_logic_vector(1 downto 0);

	
component multi_prbsgenerate_256bit is
PORT(
	coreclk  	: in std_logic;
	Enable		: in std_logic;
	StartValue	: in std_logic_vector(255 downto 0);
	Reset	 		: in std_logic;
	PrbsSelect	: in std_logic_vector(1 downto 0);
	Inserterror : in std_logic;
	Prbsout 		: out std_logic_vector(255 downto 0);
	Valid			: out std_logic;
	deskew_pulse : out std_logic -- Only for E-tile
	);
END component;		
	
component multi_prbsverify_256bit is
GENERIC
	(
		USE_ADDER_HW					:  boolean := false
	);
PORT(
	Clock  				: in std_logic;
	Enable				: in std_logic;	
	Reset	 			: in std_logic;
	ResetErrorCount 	: in std_logic;
	PrbsSelect			: in std_logic_vector(1 downto 0);
	DataIn 				: in std_logic_vector(255 downto 0);
	PrbsLocked			: out std_logic;
	Errorcount_Q 		: out std_logic_vector(63 downto 0)
	);
END component;	


BEGIN



-- Reset
Reset <= '1','0' after 500 ns;
PrbsSelect <= "10"; -- PRBS-31
--PrbsSelect <= "01"; -- PRBS-23
--PrbsSelect <= "00"; -- PRBS-13

RefClock <= not Refclock after 3200 ps;	-- 156.25 Mhz 	

-- Insert 2 single biterrors

Inserterror <= '0','1' after 10 us,'0' after 10.1 us, '1' after 20 us, '0' after 20.1 us;

PrbsGenerateX_Ch:multi_prbsgenerate_256bit
PORT MAP(
	coreclk  		=> RefClock,
	Enable			=> '1', -- see below
	Reset	 			=> Reset,
	StartValue		=> X"2222222222222222222222222222222222222222222222222222222222222222",
	PrbsSelect		=> PrbsSelect,
	Inserterror 	=> Inserterror,
	Prbsout 			=> Prbsout,
	Valid				=> valid
	);	
	

prbsverify_data_in <= Prbsout; 

PrbsVerify_Ch:multi_prbsverify_256bit 
PORT MAP(
	Clock  				=> RefClock,
	Enable				=> valid,
	Reset	 				=> Reset,
	ResetErrorCount 	=> Reset ,
	PrbsSelect			=> PrbsSelect,
	DataIn				=> prbsverify_data_in,
	PrbsLocked			=> prbslocked,
	ErrorCount_Q  		=> Errorcount
	);		
                                      
END PrbsTest_arch;
